Allocated

Struct Allocated 

pub struct Allocated<T: Release + 'static>(/* private fields */);

Implementations

Source

impl Allocated<AudioUnit>

pub unsafe fn init_with_comp_desc_opts_err<'ear>( self, desc: ComponentDesc, opts: ComponentInstantiationOpts, err: *mut Option<&'ear Error>, ) -> Option<R<AudioUnit>>

pub unsafe fn init_with_comp_desc_err<'ear>( self, desc: ComponentDesc, err: *mut Option<&'ear Error>, ) -> Option<R<AudioUnit>>

Source

impl Allocated<SysZoomSlider>

pub unsafe fn init_with_device_throws( self, device: &CaptureDevice, ) -> R<SysZoomSlider>

pub fn init_with_device<'ear>( self, device: &CaptureDevice, ) -> ExResult<'ear, R<SysZoomSlider>>

pub unsafe fn init_with_device_action_throws( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> R<SysZoomSlider>

pub fn init_with_device_action<'ear>( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> ExResult<'ear, R<SysZoomSlider>>

Source

impl Allocated<SysExposureBiasSlider>

pub unsafe fn init_with_device_throws( self, device: &CaptureDevice, ) -> R<SysExposureBiasSlider>

pub fn init_with_device<'ear>( self, device: &CaptureDevice, ) -> ExResult<'ear, R<SysExposureBiasSlider>>

pub unsafe fn init_with_device_action_throws( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> R<SysExposureBiasSlider>

pub fn init_with_device_action<'ear>( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> ExResult<'ear, R<SysExposureBiasSlider>>

Source

impl Allocated<Slider>

pub unsafe fn init_with_range_throws( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, ) -> R<Slider>

pub fn init_with_range<'ear>( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, ) -> ExResult<'ear, R<Slider>>

pub unsafe fn init_with_range_step_throws( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, step: f32, ) -> R<Slider>

pub fn init_with_range_step<'ear>( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, step: f32, ) -> ExResult<'ear, R<Slider>>

pub unsafe fn init_with_vals_throws( self, localized_title: &String, symbol_name: &String, vals: &Array<Number>, ) -> R<Slider>

pub fn init_with_vals<'ear>( self, localized_title: &String, symbol_name: &String, vals: &Array<Number>, ) -> ExResult<'ear, R<Slider>>

Source

impl Allocated<IndexPicker>

pub unsafe fn init_with_indexes_n_throws( self, localized_title: &String, symbol_name: &String, n: isize, ) -> R<IndexPicker>

pub fn init_with_indexes_n<'ear>( self, localized_title: &String, symbol_name: &String, n: isize, ) -> ExResult<'ear, R<IndexPicker>>

pub unsafe fn init_with_indexes_titles_throws( self, localized_title: &String, symbol_name: &String, titles: &Array<String>, ) -> R<IndexPicker>

pub fn init_with_titles<'ear>( self, localized_title: &String, symbol_name: &String, titles: &Array<String>, ) -> ExResult<'ear, R<IndexPicker>>

Source

impl Allocated<RotationCoordinator>

pub fn init_with_device_preview_layer( &self, device: &Device, preview_layer: Option<&Layer>, ) -> R<RotationCoordinator>

Source

impl Allocated<DeviceInput>

pub fn init_with_device_err<'ear>( self, device: &CaptureDevice, error: *mut Option<&'ear Error>, ) -> Option<R<DeviceInput>>

Source

impl Allocated<Session>

pub fn init(self) -> Retained<Session>

Source

impl Allocated<MultiCamSession>

Source

impl Allocated<Connection>

Source

impl Allocated<MetadataOutput>

Source

impl Allocated<VideoDataOutput>

Source

impl Allocated<VideoPreviewLayer>

Source

impl Allocated<PhotoOutput>

Source

impl Allocated<PhotoSettings>

Source

impl Allocated<AudioDataOutput>

Source

impl Allocated<ItemVideoOutput>

Source

impl Allocated<Player>

pub fn init_with_url(self, url: &Url) -> R<Player>

pub unsafe fn init_with_player_item_throws( self, item: Option<&PlayerItem>, ) -> R<Player>

Source

impl Allocated<QueuePlayer>

Source

impl Allocated<QueuePlayer>

pub unsafe fn init_with_items_throws( self, items: &Array<PlayerItem>, ) -> R<QueuePlayer>

Source

impl Allocated<PlayerLayer>

Source

impl Allocated<Reader>

pub unsafe fn init_with_assert_err<'ear>( self, asset: &Asset, error: *mut Option<&'ear Error>, ) -> Option<R<Reader>>

Source

impl Allocated<ReaderTrackOutput>

pub fn init_with_track_throws( self, track: &Track, output_settings: Option<&Dictionary<String, Id>>, ) -> R<ReaderTrackOutput>

Source

impl Allocated<Writer>

pub fn init_with_url_file_type_err<'ear>( self, url: &Url, file_type: &FileType, error: *mut Option<&'ear Error>, ) -> Option<R<Writer>>

pub unsafe fn init_with_content_type_throws( self, output_content_type: &Type, ) -> R<Writer>

Source

impl Allocated<WriterInput>

pub unsafe fn init_media_type_output_settings_throws( self, media_type: &MediaType, output_settings: Option<&Dictionary<String, Id>>, ) -> R<WriterInput>

pub unsafe fn with_media_type_output_settings_source_format_hint_throws( self, media_type: &MediaType, output_settings: Option<&Dictionary<String, Id>>, source_format_hint: Option<&FormatDesc>, ) -> R<WriterInput>

Source

impl Allocated<WriterInputPixelBufAdaptor>

Source

impl Allocated<ImageGenerator>

pub fn init_with_asset(self, asset: &Asset) -> R<ImageGenerator>

Source

impl Allocated<UrlAsset>

pub fn init_with_url_opts( self, url: &Url, options: Option<&Dictionary<String, Id>>, ) -> Option<R<UrlAsset>>

Source

impl Allocated<Effect>

Source

impl Allocated<UnitEq>

pub fn init_with_number_of_bands(self, number_of_bands: usize) -> R<UnitEq>

Source

impl Allocated<TimeEffect>

Source

impl Allocated<Mix>

pub fn init(self) -> Retained<Mix>

Source

impl Allocated<MixMut>

pub fn init(self) -> Retained<MixMut>

Source

impl Allocated<InputParams>

Source

impl Allocated<InputParamsMut>

Source

impl Allocated<MixerNode>

pub fn init(self) -> Retained<MixerNode>

Source

impl Allocated<Time>

pub fn init_with_audio_ts_sample_rate( self, ts: &AudioTimeStamp, sample_rate: f64, ) -> R<Time>

pub fn init_with_host_time(self, host_time: u64) -> R<Time>

pub fn init_with_host_time_sample_rate_at_rate( self, host_time: u64, sample_time: FramePos, at_rate: f64, ) -> R<Time>

pub fn init_with_sample_time_at_rate( self, time: FramePos, at_rate: f64, ) -> R<Time>

Source

impl Allocated<Engine>

pub fn init(self) -> Retained<Engine>

Source

impl Allocated<Player>

pub unsafe fn init_with_url_err<'ear>( self, url: &Url, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>

pub unsafe fn init_with_data_err<'ear>( self, data: &Data, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>

pub unsafe fn init_with_url_hint_err<'ear>( self, url: &Url, hint: Option<&String>, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>

pub unsafe fn init_with_data_hint_err<'ear>( self, data: &Data, hint: Option<&String>, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>

Source

impl Allocated<PlayerNode>

pub fn init(self) -> Retained<PlayerNode>

Source

impl Allocated<PcmBuf>

pub fn init_with_pcm_format_frame_capacity( self, format: &Format, frame_capacity: FrameCount, ) -> Option<R<PcmBuf>>

pub fn init_with_pcm_format_buf_list_no_copy<const N: usize>( self, format: &Format, buf_list: &AudioBufList<N>, deallocator: Option<&mut EscBlock<fn(buf_list: *const AudioBufList<N>)>>, ) -> Option<R<PcmBuf>>

Source

impl Allocated<CompressedBuf>

pub fn init_with_format_and_packet_capacity( self, format: &Format, packet_capacity: PacketCount, ) -> R<CompressedBuf>

pub fn init_with_format_packet_capacity_and_maximum_packet_size( self, format: &Format, packet_capacity: PacketCount, maximum_packet_size: isize, ) -> R<CompressedBuf>

Source

impl Allocated<Format>

Source

impl Allocated<File>

pub unsafe fn init_for_reading_err_ar<'ear>( self, file_url: &Url, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>

pub unsafe fn init_for_reading_err<'ear>( self, file_url: &Url, err: *mut Option<&'ear Error>, ) -> Option<R<File>>

pub unsafe fn init_for_reading_common_format_err_ar<'ear>( self, file_url: &Url, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>

pub unsafe fn init_for_reading_common_format_err<'ear>( self, file_url: &Url, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<R<File>>

pub unsafe fn init_for_writing_err_ar<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>

pub unsafe fn init_for_writing_err<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<File>>

pub unsafe fn init_for_writing_common_format_err_ar<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>

pub unsafe fn init_for_writing_common_format_err<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<R<File>>

Source

impl Allocated<ChannelLayout>

Source

impl Allocated<ConnectionPoint>

pub fn init_with_node_bus(self, node: &Node, bus: NodeBus) -> R<ConnectionPoint>

Source

impl Allocated<Converter>

Source

impl Allocated<Voice>

pub fn init(self) -> Retained<Voice>

Source

impl Allocated<Utterance>

pub fn init(self) -> Retained<Utterance>

Source

impl Allocated<Utterance>

pub fn init_with_string(self, val: &String) -> R<Utterance>

pub fn init_with_attr_string(self, val: &AttrString) -> R<Utterance>

pub fn init_with_ssml(self, val: &String) -> R<Utterance>

Source

impl Allocated<Synthesizer>

Source

impl Allocated<DisplayLayer>

Source

impl Allocated<VideoRenderer>

Source

impl Allocated<PipController>

pub fn init_with_content_src( self, content_src: &PipControllerContentSrc, ) -> R<PipController>

pub fn sel_init_with_content_src() -> &'static Sel

@selector(initWithContentSource:) but dynamic use this function to check if object responds to selector

pub fn init_with_player_layer( self, player_layer: &PlayerLayer, ) -> Option<R<PipController>>

Source

impl Allocated<PipControllerContentSrc>

pub fn init_with_player_layer( self, player_layer: &PlayerLayer, ) -> R<PipControllerContentSrc>

pub fn sel_init_with_player_layer() -> &'static Sel

@selector(initWithPlayerLayer:) but dynamic use this function to check if object responds to selector

Source

impl Allocated<PipControllerContentSrc>

Source

impl Allocated<PlaybackSpeed>

pub fn init_with_rate( self, rate: f32, localized_name: &String, ) -> R<PlaybackSpeed>

Source

impl Allocated<DisplayLink>

Source

impl Allocated<Animation>

pub fn init(self) -> Retained<Animation>

Source

impl Allocated<MediaTimingFn>

pub fn init_with_ctrl_points( self, c1x: f32, c1y: f32, c2x: f32, c2y: f32, ) -> R<MediaTimingFn>

Source

impl Allocated<Layer>

pub fn init(self) -> Retained<Layer>

Source

impl Allocated<MetalLayer>

pub fn init(self) -> Retained<MetalLayer>

Source

impl Allocated<Transaction>

Source

impl Allocated<Context>

pub fn init(self) -> Retained<Context>

Source

impl Allocated<Context>

pub fn init_with_opts( self, options: Option<&Dictionary<String, Id>>, ) -> Option<R<Context>>

Source

impl Allocated<Image>

Source

impl Allocated<Vec>

pub fn init_with_vals(self, values: *const Float, count: usize) -> R<Vec>

pub fn init_ns_string(self, val: &String) -> R<Vec>

Source

impl Allocated<LocationManager>

Source

impl Allocated<Location>

pub fn init(self) -> Retained<Location>

Source

impl Allocated<Location>

Source

impl Allocated<TapDesc>

pub fn init(self) -> Retained<TapDesc>

Source

impl Allocated<TapDesc>

pub fn init_stereo_mixdown_of_processes_ar( self, processes_obj_ids_to_include: &Array<Number>, ) -> Rar<TapDesc>

pub fn init_stereo_mixdown_of_processes( self, processes_obj_ids_to_include: &Array<Number>, ) -> R<TapDesc>

pub fn init_stereo_global_tap_but_exclude_processes_ar( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> Rar<TapDesc>

pub fn init_stereo_global_tap_but_exclude_processes( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> R<TapDesc>

pub fn init_mono_mixdown_of_processes_ar( self, processes_obj_ids_to_include: &Array<Number>, ) -> Rar<TapDesc>

pub fn init_mono_mixdown_of_processes( self, processes_obj_ids_to_include: &Array<Number>, ) -> R<TapDesc>

pub fn init_mono_global_tap_but_exclude_processes_ar( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> Rar<TapDesc>

pub fn init_mono_global_tap_but_exclude_processes( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> R<TapDesc>

pub fn init_with_processes_and_device( self, processes_obj_ids_to_include: &Array<Number>, device_uid: &String, stream: isize, ) -> R<TapDesc>

pub fn init_excluding_processes_and_device_ar( self, processes_obj_ids_to_exclude: &Array<Number>, device_uid: &String, stream: isize, ) -> Rar<TapDesc>

pub fn init_excluding_processes_and_device( self, processes_obj_ids_to_exclude: &Array<Number>, device_uid: &String, stream: isize, ) -> R<TapDesc>

Source

impl Allocated<HeadphoneMotionManager>

Source

impl Allocated<MotionManager>

Source

impl Allocated<Pedometer>

pub fn init(self) -> Retained<Pedometer>

Source

impl Allocated<Color>

pub fn init_with_rgb(self, r: f32, g: f32, b: f32) -> R<Color>

Source

impl Allocated<BrowserViewController>

pub unsafe fn init_with_service_type_throws( self, service_type: &String, session: &Session, ) -> R<BrowserViewController>

pub unsafe fn init_with_browser_throws( self, browser: &NearbyServiceBrowser, session: &Session, ) -> R<BrowserViewController>

Source

impl Allocated<PeerId>

pub unsafe fn init_with_display_name_throws( self, display_name: &String, ) -> R<PeerId>

Source

impl Allocated<Session>

pub unsafe fn init_with_peer_throws(self, peer: &PeerId) -> R<Session>

pub unsafe fn init_with_encryption_throws( self, peer: &PeerId, sec_identity: Option<&Array<Id>>, encryption_preference: EncryptionPreference, ) -> R<Session>

Source

impl Allocated<AdvertiserAssistant>

pub unsafe fn init_service_type_throws_ar( self, peer: &PeerId, service_type: &String, ) -> Rar<AdvertiserAssistant>

pub unsafe fn init_service_type_throws( self, peer: &PeerId, service_type: &String, ) -> R<AdvertiserAssistant>

Source

impl Allocated<NearbyServiceAdvertiser>

pub unsafe fn init_with_peer_throws( self, my_peer: &PeerId, discorvery_info: Option<&Dictionary<String, String>>, service_type: &String, ) -> R<NearbyServiceAdvertiser>

Source

impl Allocated<NearbyServiceBrowser>

pub unsafe fn init_with_peer_and_service_type_throws( self, peer: &PeerId, service_type: &String, ) -> R<NearbyServiceBrowser>

Source

impl Allocated<GeometryDesc>

Source

impl Allocated<TriangleGeometryDesc>

pub fn init(self) -> Retained<TriangleGeometryDesc>

Source

impl Allocated<MotionBoundingBoxGeometryDesc>

Source

impl Allocated<TensorExtents>

Source

impl Allocated<TensorExtents>

pub fn sel_init_with_rank() -> &'static Sel

@selector(initWithRank:values:) but dynamic use this function to check if object responds to selector

pub unsafe fn init_with_rank( self, rank: usize, values: *const usize, ) -> Option<R<TensorExtents>>

Source

impl Allocated<TensorDesc>

pub fn init(self) -> Retained<TensorDesc>

Source

impl Allocated<Tensor>

pub fn init(self) -> Retained<Tensor>

Source

impl Allocated<ResidencySetDesc>

Source

impl Allocated<CompileOpts>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<FnConstValues>

Source

impl Allocated<FnStitchingAttrAlwaysInline>

Source

impl Allocated<FnStitchingInputNode>

Source

impl Allocated<FnStitchingInputNode>

Source

impl Allocated<FnStitchingFnNode>

pub fn init_with_name( self, name: &String, args: &Array<FnStitchingNode>, control_deps: &Array<FnStitchingFnNode>, ) -> R<FnStitchingFnNode>

Source

impl Allocated<FnStitchingGraph>

pub fn init_with_fn_name( self, fn_name: &String, nodes: &Array<FnStitchingFnNode>, output_node: Option<&FnStitchingFnNode>, attribtues: &Array<FnStitchingAttr>, ) -> R<FnStitchingGraph>

Source

impl Allocated<FnStitchedLibDesc>

Source

impl Allocated<FnDesc>

pub fn init(self) -> Retained<FnDesc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<TileRenderPipelineDesc>

Source

impl Allocated<SharedEventListener>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<StencilDesc>

Source

impl Allocated<DepthStencilDesc>

Source

impl Allocated<VertexBufLayoutDesc>

Source

impl Allocated<VertexAttrDesc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<Desc>

pub fn init(self) -> Retained<Desc>

Source

impl Allocated<PipelineBufDesc>

Source

impl Allocated<CaptureDesc>

Source

impl Allocated<FrameInterpolatorDesc>

Source

impl Allocated<TemporalDenoisedScalerDesc>

Source

impl Allocated<SpatialScaleDesc>

Source

impl Allocated<ArgTableDesc>

Source

impl Allocated<CounterHeapDesc>

Source

impl Allocated<CmdAllocatorDesc>

Source

impl Allocated<CmdBufOpts>

pub fn init(self) -> Retained<CmdBufOpts>

Source

impl Allocated<CommitOpts>

pub fn init(self) -> Retained<CommitOpts>

Source

impl Allocated<CmdQueueDesc>

Source

impl Allocated<CompilerDesc>

Source

impl Allocated<RenderPassDesc>

Source

impl Allocated<MlPipelineDesc>

Source

impl Allocated<PipelineOpts>

Source

impl Allocated<TextureLoader>

pub fn init_with_device(self, device: &Device) -> R<TextureLoader>

Source

impl Allocated<Device>

pub fn init(self) -> Retained<Device>

Source

impl Allocated<Graph>

pub fn init(self) -> Retained<Graph>

Source

impl Allocated<TrainingGraph>

Source

impl Allocated<ExecutionDesc>

Source

impl Allocated<Executable>

pub fn init(self) -> Retained<Executable>

Source

impl Allocated<Executable>

pub fn init_with_mps_graph_package_at_url( self, mps_graph_package_url: &Url, compilation_descriptor: Option<&CompilationDesc>, ) -> R<Executable>

pub fn sel_init_with_mps_graph_package_at_url() -> &'static Sel

@selector(initWithMPSGraphPackageAtURL:compilationDescriptor:) but dynamic use this function to check if object responds to selector

pub fn init_with_core_ml_package_at_url( self, core_ml_package_url: &Url, compilation_descriptor: Option<&CompilationDesc>, ) -> R<Executable>

pub fn sel_init_with_core_ml_package_at_url() -> &'static Sel

@selector(initWithCoreMLPackageAtURL:compilationDescriptor:) but dynamic use this function to check if object responds to selector

Source

impl Allocated<TensorData>

pub fn init(self) -> Retained<TensorData>

Source

impl Allocated<TensorData>

pub fn init_with_device_data_shape_data_type( self, device: &Device, data: &Data, shape: &Shape, data_type: DType, ) -> R<TensorData>

pub fn init_with_mtl_buffer_shape_data_type( self, buffer: &Buf, shape: &Shape, data_type: DType, ) -> R<TensorData>

pub fn init_with_mtl_buffer_shape_data_type_row_bytes( self, buffer: &Buf, shape: &Shape, data_type: DType, row_bytes: usize, ) -> R<TensorData>

pub fn sel_init_with_mtl_buffer_shape_data_type_row_bytes() -> &'static Sel

@selector(initWithMTLBuffer:shape:dataType:rowBytes:) but dynamic use this function to check if object responds to selector

pub fn init_with_mps_nd_array(self, ndarray: &NdArray) -> R<TensorData>

Source

impl Allocated<SingleGateRnnDesc>

Source

impl Allocated<LstmDesc>

pub fn init(self) -> Retained<LstmDesc>

Source

impl Allocated<GruDescr>

pub fn init(self) -> Retained<GruDescr>

Source

impl Allocated<CompilationDesc>

Source

impl Allocated<ExecutionDesc>

Source

impl Allocated<Graph>

pub fn init(self) -> Retained<Graph>

Source

impl Allocated<ArrayBatchProvider>

pub fn init_with_feature_provider_array<P: FeatureProvider>( self, arr: &Array<P>, ) -> R<ArrayBatchProvider>

pub unsafe fn init_with_dictionary<'ear>( self, dictionary: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<ArrayBatchProvider>>

Source

impl Allocated<DictionaryFeatureProvider>

pub unsafe fn init_with_dictionary_err<'ear>( self, dictionary: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<DictionaryFeatureProvider>>

Source

impl Allocated<FeatureValue>

Source

impl Allocated<MultiArray>

pub fn init(self) -> Retained<MultiArray>

Source

impl Allocated<MultiArray>

pub unsafe fn init_with_shape_err<'ear>( self, shape: &Array<Number>, d_type: MultiArrayDType, err: *mut Option<&'ear Error>, ) -> Option<R<MultiArray>>

pub fn init_with_shape_strides( self, shape: &Array<Number>, d_type: MultiArrayDType, strides: &Array<Number>, ) -> R<MultiArray>

pub unsafe fn init_with_ptr<'ear>( self, data_ptr: *mut c_void, shape: &Array<Number>, d_type: MultiArrayDType, strides: &Array<Number>, deallocator: Option<&mut EscBlock<fn(ptr: *mut c_void)>>, error: *mut Option<&'ear Error>, ) -> Option<R<MultiArray>>

pub unsafe fn init_with_pixel_buf_throws( self, pixel_buf: &PixelBuf, shape: &Array<Number>, ) -> R<MultiArray>

Source

impl Allocated<PredictionOpts>

Source

impl Allocated<ModelCfg>

pub fn init(self) -> Retained<ModelCfg>

Source

impl Allocated<Bundle>

pub fn init_with_path(self, path: &String) -> Option<R<Bundle>>

Source

impl Allocated<Predicate>

pub fn init(self) -> Retained<Predicate>

Source

impl Allocated<DateFormatter>

Source

impl Allocated<Iso8601DateFormatter>

Source

impl Allocated<Port>

pub fn init(self) -> Retained<Port>

Source

impl Allocated<MachPort>

pub fn init(self) -> Retained<MachPort>

Source

impl Allocated<UrlRequest>

pub fn init_with_url(self, url: &Url) -> R<UrlRequest>

pub fn init_with_url_cache_policy_timeout( self, url: &Url, cache_policy: CachePolicy, timeout: TimeInterval, ) -> R<UrlRequest>

Source

impl Allocated<UrlRequestMut>

pub fn init_with_url(self, url: &Url) -> R<UrlRequestMut>

pub fn init_with_url_cache_policy_timeout( self, url: &Url, cache_policy: CachePolicy, timeout: TimeInterval, ) -> R<UrlRequestMut>

Source

impl Allocated<WebSocketMessage>

pub fn init_with_data(self, data: &Data) -> R<WebSocketMessage>

pub fn init_with_string(self, string: &String) -> R<WebSocketMessage>

Source

impl Allocated<UrlCache>

pub fn init_with_capacity( self, mem_capacity: usize, disk_capacity: usize, directory_url: Option<&Url>, ) -> R<UrlCache>

Source

impl Allocated<UserActivity>

pub fn init_with_activity_type(self, activity_type: &String) -> R<UserActivity>

Source

impl Allocated<UserDefaults>

Source

impl Allocated<UserDefaults>

Source

impl Allocated<IndexPath>

pub fn init(self) -> Retained<IndexPath>

Source

impl Allocated<IndexPath>

pub fn init_with_index(self, index: usize) -> R<IndexPath>

pub fn init_with_indexes( self, indexes: *const usize, lenght: usize, ) -> R<IndexPath>

Source

impl Allocated<IndexSet>

pub fn init_with_index(self, val: usize) -> R<IndexSet>

pub fn init_with_index_set(self, val: &IndexSet) -> R<IndexSet>

pub fn init_with_range(self, val: Range) -> R<IndexSet>

Source

impl Allocated<IndexSetMut>

Source

impl Allocated<IndexSet>

pub fn init(self) -> Retained<IndexSet>

Source

impl Allocated<IndexSetMut>

Source

impl<T: Obj> Allocated<Array<T>>

pub fn init_ar(self) -> Rar<Array<T>>

Initializes an empty array.

pub fn init(self) -> R<Array<T>>

Initializes an empty array.

pub unsafe fn init_with_objs(self, ptr: *const &T, count: usize) -> R<Array<T>>

Initializes from a raw pointer to Objective-C object references.

Safety

ptr must point to count valid references for the duration of the call.

Source

impl<T: Obj> Allocated<ArrayMut<T>>

pub fn init_with_capacity(self, capacity: usize) -> R<ArrayMut<T>>

pub unsafe fn init_with_objs( &self, ptr: *const &T, count: usize, ) -> R<ArrayMut<T>>

Source

impl<K: Obj, V: Obj> Allocated<Dictionary<K, V>>

pub fn init_ar(self) -> Rar<Dictionary<K, V>>

pub fn init(self) -> R<Dictionary<K, V>>

pub unsafe fn init_with_objs_for_keys_count_throws( self, objects: *const V, keys: *const K, count: usize, ) -> R<Dictionary<K, V>>

Source

impl<K: Obj, V: Obj> Allocated<DictionaryMut<K, V>>

pub fn init_ar(self) -> Rar<DictionaryMut<K, V>>

pub fn init(self) -> R<DictionaryMut<K, V>>

pub fn init_with_capacity(self, capacity: usize) -> R<DictionaryMut<K, V>>

Source

impl<T: Obj> Allocated<Set<T>>

pub fn init_ar(self) -> Rar<Set<T>>

pub fn init(self) -> R<Set<T>>

pub fn init_with_objs_count(self, ptr: *const c_void, count: usize) -> R<Set<T>>

Source

impl<T: Obj> Allocated<SetMut<T>>

pub fn init_ar(self) -> Rar<SetMut<T>>

pub fn init(self) -> R<SetMut<T>>

pub fn init_with_capacity(self, capacity: usize) -> R<SetMut<T>>

Source

impl Allocated<Data>

pub fn init(self) -> Retained<Data>

Source

impl Allocated<DataMut>

pub fn init(self) -> Retained<DataMut>

Source

impl Allocated<Data>

pub fn init_with_contents_of_file_opts_err<'ear>( self, path: &String, options: ReadOpts, error: *mut Option<&'ear Error>, ) -> Option<R<Data>>

pub fn init_with_contents_of_url_opts_err<'ear>( self, url: &Url, options: ReadOpts, error: *mut Option<&'ear Error>, ) -> Option<R<Data>>

pub fn init_with_bytes(self, bytes: *const u8, length: usize) -> R<Data>

Source

impl Allocated<Regex>

pub fn init_with_pattern_opts_err<'ear>( self, pattern: &String, opts: Opts, error: *mut Option<&'ear Error>, ) -> Option<R<Regex>>

Source

impl Allocated<String>

pub fn init(self) -> Retained<String>

Source

impl Allocated<StringMut>

pub fn init(self) -> Retained<StringMut>

Source

impl Allocated<String>

pub fn init_with_bytes_length_encoding( self, bytes: *const u8, length: usize, encoding: StringEncoding, ) -> Option<R<String>>

pub fn init_with_bytes_no_copy_length_encoding_free_when_done( self, bytes: *const u8, length: usize, encoding: StringEncoding, free_when_done: bool, ) -> Option<R<String>>

Source

impl Allocated<StringMut>

pub fn with_capacity(self, capacity: usize) -> R<StringMut>

Source

impl Allocated<AttrString>

pub fn init(self) -> Retained<AttrString>

Source

impl Allocated<AttrString>

Source

impl Allocated<AttrStringMut>

Source

impl Allocated<AttrStringMut>

Source

impl Allocated<Url>

pub fn init_with_path_is_dir_relative_to_url_ar( self, path: &String, is_dir: bool, relative_to: Option<&Url>, ) -> Rar<Url>

pub fn init_with_path_is_dir_relative_to_url( self, path: &String, is_dir: bool, relative_to: Option<&Url>, ) -> R<Url>

pub fn init_with_string_relative_to( self, string: &String, relative_to: Option<&Url>, ) -> Option<R<Url>>

Source

impl Allocated<Uuid>

pub fn init(self) -> Retained<Uuid>

Source

impl Allocated<RunLoop>

pub fn init(self) -> Retained<RunLoop>

Source

impl Allocated<Date>

pub fn init(self) -> Retained<Date>

Source

impl Allocated<Date>

Source

impl Allocated<Error>

pub fn init_with_domain( self, domain: &ErrorDomain, code: Integer, user_info: Option<&Dictionary<String, Id>>, ) -> R<Error>

Source

impl Allocated<Thread>

pub fn init(self) -> Retained<Thread>

Source

impl Allocated<Timer>

pub fn init_with_fire_date_block( self, date: &Date, interval: TimeInterval, repeats: bool, block: &mut SyncBlock<fn(timer: &mut Timer)>, ) -> R<Timer>

pub fn init_with_fire_date_sel( self, date: &Date, interval: TimeInterval, target: &Id, selector: &Sel, user_info: Option<&Id>, repeats: bool, ) -> R<Timer>

Source

impl Allocated<Notification>

pub fn init_with_name( self, name: &NotificationName, object: Option<&Id>, user_info: Option<&Dictionary<Id, Id>>, ) -> R<Notification>

pub fn init_with_coder(self, coder: &Coder) -> R<Notification>

Source

impl Allocated<NotificationCenter>

Source

impl Allocated<OpQueue>

pub fn init(self) -> Retained<OpQueue>

Source

impl Allocated<Coder>

pub fn init(self) -> Retained<Coder>

Source

impl Allocated<Locale>

pub fn init_with_locale_id(self, id: &String) -> R<Locale>

Source

impl<S: Obj, I: Obj> Allocated<DiffableDataSrcSnapshot<S, I>>

pub fn init_ar(self) -> Rar<DiffableDataSrcSnapshot<S, I>>

pub fn init(self) -> R<DiffableDataSrcSnapshot<S, I>>

Source

impl<T: Obj> Allocated<OrderedCollectionChange<T>>

Source

impl<T: Obj> Allocated<OrderedCollectionDiff<T>>

Source

impl Allocated<AnimationCtx>

Source

impl Allocated<Button>

pub fn init(self) -> Retained<Button>

Source

impl Allocated<Cell>

pub fn init_text_cell_ar(self, string: &String) -> Rar<Cell>

pub fn init_text_cell(self, string: &String) -> R<Cell>

pub fn init_image_cell_ar(self, image: Option<&Image>) -> Rar<Cell>

pub fn init_image_cell(self, image: Option<&Image>) -> R<Cell>

Source

impl Allocated<Cell>

pub fn init(self) -> Retained<Cell>

Source

impl Allocated<CollectionView>

Source

impl Allocated<CollectionViewItem>

Source

impl Allocated<ColorSpace>

pub fn init(self) -> Retained<ColorSpace>

Source

impl Allocated<ColorSpace>

Source

impl Allocated<Color>

pub fn init(self) -> Retained<Color>

Source

impl<S: Obj, I: Obj> Allocated<CollectionViewDiffableDataSrc<S, I>>

Source

impl Allocated<Event>

pub fn init(self) -> Retained<Event>

Source

impl Allocated<Font>

pub fn init(self) -> Retained<Font>

Source

impl Allocated<FontManager>

Source

impl Allocated<GestureRecognizer>

pub fn init_with_target( self, target: Option<&Id>, action: Option<&Sel>, ) -> R<GestureRecognizer>

Source

impl Allocated<GestureRecognizer>

Source

impl Allocated<Image>

pub fn init(self) -> Retained<Image>

Source

impl Allocated<Menu>

pub fn init(self) -> Retained<Menu>

Source

impl Allocated<Menu>

pub fn init_with_title(self, title: &String) -> R<Menu>

Source

impl Allocated<Pasteboard>

pub fn init(self) -> Retained<Pasteboard>

Source

impl Allocated<Responder>

pub fn init(self) -> Retained<Responder>

Source

impl Allocated<RunningApp>

pub fn init(self) -> Retained<RunningApp>

Source

impl Allocated<Screen>

pub fn init(self) -> Retained<Screen>

Source

impl Allocated<SplitViewItem>

Source

impl Allocated<TextField>

pub fn init(self) -> Retained<TextField>

Source

impl Allocated<TitlebarAccessoryViewController>

Source

impl Allocated<ViewController>

Source

impl Allocated<View>

pub fn init(self) -> Retained<View>

Source

impl Allocated<View>

pub fn init_with_frame(self, frame: Rect) -> R<View>

Source

impl Allocated<Toolbar>

pub fn init(self) -> Retained<Toolbar>

Source

impl Allocated<Toolbar>

pub fn init_with_id(self, id: &ToolbarId) -> R<Toolbar>

Source

impl Allocated<ToolbarItem>

Source

impl Allocated<ToolbarItem>

Source

impl Allocated<StatusBar>

pub fn init(self) -> Retained<StatusBar>

Source

impl Allocated<WindowController>

Source

impl Allocated<WindowController>

Source

impl Allocated<Window>

pub fn init(self) -> Retained<Window>

Source

impl Allocated<Window>

pub fn init_with_content_rect_style_mask_backing_defer( self, content_rect: Rect, style: WindowStyleMask, backing: BackingStoreType, defer: bool, ) -> R<Window>

Source

impl Allocated<WorkspaceOpenCfg>

Source

impl Allocated<Connection>

pub fn init_with_service_name(self, name: &String) -> R<Connection>

pub fn init_with_mach_service( self, name: &String, options: ConnectionOptions, ) -> R<Connection>

pub fn init_with_listener_endpoint( self, endpoint: &ListenerEndpoint, ) -> R<Connection>

Source

impl Allocated<Listener>

pub fn init_with_mach_service_name(self, name: &String) -> R<Listener>

Source

impl Allocated<TextAttachment>

Source

impl Allocated<TextAttachment>

pub fn init_with_data( self, data: Option<&Data>, type_: Option<&String>, ) -> R<TextAttachment>

Source

impl Allocated<LangRecognizer>

Source

impl Allocated<Embedding>

pub fn init(self) -> Retained<Embedding>

Source

impl Allocated<Cfg>

pub fn init(self) -> Retained<Cfg>

Source

impl Allocated<Cfg>

pub fn init(self) -> Retained<Cfg>

Source

impl Allocated<ContentFilter>

pub fn init_with_desktop_independent_window( self, window: &Window, ) -> Retained<ContentFilter>

pub fn sel_init_with_desktop_independent_window() -> &'static Sel

@selector(initWithDesktopIndependentWindow:) but dynamic use this function to check if object responds to selector

pub fn init_with_display_excluding_windows( self, display: &Display, windows: &Array<Window>, ) -> Retained<ContentFilter>

pub fn sel_init_with_display_excluding_windows() -> &'static Sel

@selector(initWithDisplay:excludingWindows:) but dynamic use this function to check if object responds to selector

pub fn init_with_display_including_windows( self, display: &Display, windows: &Array<Window>, ) -> Retained<ContentFilter>

Creates a content filter that includes only the specified windows on the given display.

Use this initializer to capture specific windows from a display. Unlike init_with_desktop_independent_window, this method works reliably for all window types including regular application windows.

pub fn sel_init_with_display_including_windows() -> &'static Sel

@selector(initWithDisplay:includingWindows:) but dynamic use this function to check if object responds to selector

pub fn init_with_display_including_apps_excepting_windows( self, display: &Display, apps: &Array<RunningApp>, excepting_windows: &Array<Window>, ) -> Retained<ContentFilter>

Creates a content filter that includes content from the specified applications, optionally excluding specific windows.

pub fn sel_init_with_display_including_apps_excepting_windows() -> &'static Sel

@selector(initWithDisplay:includingApplications:exceptingWindows:) but dynamic use this function to check if object responds to selector

pub fn init_with_display_excluding_apps_excepting_windows( self, display: &Display, apps: &Array<RunningApp>, excepting_windows: &Array<Window>, ) -> Retained<ContentFilter>

Creates a content filter that excludes content from the specified applications, optionally excepting specific windows that should still be included.

pub fn sel_init_with_display_excluding_apps_excepting_windows() -> &'static Sel

@selector(initWithDisplay:excludingApplications:exceptingWindows:) but dynamic use this function to check if object responds to selector

Source

impl Allocated<Stream>

pub fn init_with_filter_configuration_delegate<D: Delegate>( self, filter: &ContentFilter, configuration: &Cfg, delegate: Option<&D>, ) -> Retained<Stream>

Initializes a stream with a content filter, configuration, and optional delegate.

Source

impl Allocated<ScreenshotCfg>

Source

impl Allocated<ScreenshotOutput>

Source

impl Allocated<RecordingOutputCfg>

Source

impl Allocated<RecordingOutput>

pub fn init_with_cfg_delegate<D: Delegate>( self, cfg: &RecordingOutputCfg, delegate: &D, ) -> Retained<RecordingOutput>

Initializes a recording output with a configuration and delegate.

Source

impl Allocated<ClipBufferingOutput>

pub fn sel_init_with_delegate() -> &'static Sel

@selector(initWithDelegate:) but dynamic use this function to check if object responds to selector

pub unsafe fn init_with_delegate<D: Delegate>( self, delegate: Option<&D>, ) -> Retained<ClipBufferingOutput>

Initializes a clip buffering output with an optional delegate.

Source

impl Allocated<RecordingEditor>

pub fn sel_init_with_url() -> &'static Sel

@selector(initWithURL:) but dynamic use this function to check if object responds to selector

pub unsafe fn init_with_url(self, url: &Url) -> Retained<RecordingEditor>

Initializes an editor for a recording file URL.

Source

impl Allocated<AudioStreamAnalyzer>

Source

impl Allocated<AudioStreamAnalyzer>

Source

impl Allocated<AudioFileAnalyzer>

Source

impl Allocated<AudioFileAnalyzer>

pub unsafe fn init_with_url_err<'ear>( self, url: &Url, error: *mut Option<&'ear Error>, ) -> Option<R<AudioFileAnalyzer>>

Source

impl Allocated<Constraint>

pub fn init_with_duration_range( self, duration_range: TimeRange, ) -> R<Constraint>

pub fn init_with_enumerated_durations( self, durations: &Array<Value>, ) -> R<Constraint>

Source

impl Allocated<ClassifySoundRequest>

pub unsafe fn init_with_classifier_id_err<'ear>( self, id: &Id, err: *mut Option<&'ear Error>, ) -> Option<R<ClassifySoundRequest>>

Source

impl Allocated<ClassificationResult>

Source

impl Allocated<NotificationContent>

Source

impl Allocated<NotificationContentMut>

Source

impl Allocated<CalcImageAestheticsScoresRequest>

Source

impl Allocated<CalcImageAestheticsScoresRequest>

Source

impl Allocated<DetectHorizonRequest>

Source

impl Allocated<ImageRequestHandler>

Source

impl Allocated<SequenceRequestHandler>

Source

impl Allocated<StatefulRequest>

pub fn init_with_frame_analysis_spacing_ch( self, frame_analysis_spacing: Time, ch: Option<&mut RequestCh>, ) -> R<StatefulRequest>

Source

impl Allocated<RecognizeTextRequest>

Source

impl Allocated<RecognizeAnimalsRequest>

Source

impl Allocated<GenForegroundInstanceMaskRequest>

Source

impl Allocated<GenPersonSegmentationRequest>

Source

impl Allocated<DetectDocumentSegmentationRequest>

Source

impl Allocated<GenAttentionBasedSaliencyImageRequest>

Source

impl Allocated<GenObjectnessBasedSaliencyImageRequest>

Source

impl Allocated<GenImageFeaturePrintRequest>

Source

impl Allocated<GenImageFeaturePrintRequest>

Source

impl Allocated<ClassifyImageRequest>

Source

impl Allocated<DetectFaceRectanglesRequest>

Source

impl Allocated<DetectFaceCaptureQualityRequest>

Source

impl Allocated<DetectBarcodesRequest>

Source

impl Allocated<FrameRateCadence>

pub fn init_with_frame_rate(self, frame_rate: isize) -> R<FrameRateCadence>

Source

impl Allocated<TimeIntervalCadence>

Source

impl Allocated<RequestProcessingOpts>

Source

impl Allocated<VideoProcessor>

pub fn init_with_url(self, url: &Url) -> R<VideoProcessor>

pub fn sel_init_with_url() -> &'static Sel

@selector(initWithURL:) but dynamic use this function to check if object responds to selector

Source

impl Allocated<WebView>

pub fn init(self) -> Retained<WebView>

Source

impl Allocated<WebView>

pub fn init_with_frame_cfg(self, frame: Rect, cfg: &WebViewCfg) -> R<WebView>

Source

impl Allocated<WebViewCfg>

pub fn init(self) -> Retained<WebViewCfg>

Source

impl Allocated<ProcessPool>

Source

impl Allocated<Preferences>

Source

impl Allocated<UserContentController>

Source

impl Allocated<UserScript>

pub fn init_with_src_injection_time_for_main_frame_only( self, src: &String, injection_time: UserScriptInjectionTime, for_main_frame_only: bool, ) -> R<UserScript>