UnitTimeEffect

Struct UnitTimeEffect 

pub struct UnitTimeEffect(/* private fields */);

Implementations

Source

impl TimeEffect

pub fn retained(&self) -> R<Self>

Source

impl TimeEffect

Unit that processes audio in non real-time

An TimeEffect represents an audio unit of type aufc. These effects do not process audio in real-time. The varispeed unit is an example of a time effect unit.

AVAudioUnitTimeEffect

pub fn cls() -> &'static Class<Self>

pub fn cls_ptr() -> *const c_void

pub fn alloc() -> A<Self>

pub fn bypass(&self) -> bool

pub fn set_bypass(&mut self, value: bool)

pub fn with_component_desc(description: ComponentDesc) -> R<Self>

Methods from Deref<Target = Unit>

pub fn retained(&self) -> R<Self>

Methods from Deref<Target = Node>

pub fn retained(&self) -> R<Self>

pub fn reset(&self)

pub fn input_format_for_bus_ar(&self, bus: AudioNodeBus) -> Rar<AudioFormat>

pub fn input_format_for_bus(&self, bus: AudioNodeBus) -> R<AudioFormat>

pub fn output_format_for_bus_ar(&self, bus: AudioNodeBus) -> Rar<AudioFormat>

pub fn output_format_for_bus(&self, bus: AudioNodeBus) -> R<AudioFormat>

pub fn name_for_input_bus_ar(&self, bus: AudioNodeBus) -> Option<Rar<String>>

Gets the name of the input bus you specify.

pub fn name_for_input_bus(&self, bus: AudioNodeBus) -> Option<R<String>>

Gets the name of the input bus you specify.

pub fn engine_ar(&self) -> Option<Rar<Engine>>

pub fn engine(&self) -> Option<R<Engine>>

pub fn number_of_inputs(&self) -> usize

The node’s number of input busses.

pub fn number_of_outputs(&self) -> usize

The node’s number of output busses.

pub fn last_render_time(&self) -> Option<AudioTime>

Obtain the time for which the node most recently rendered.

Will return None if the engine is not running or if the node is not connected to an input or output node.

pub fn audio_unit_ar(&self) -> Rar<AudioUnit>

pub fn audio_unit(&self) -> R<AudioUnit>

pub fn latency(&self) -> TimeInterval

The processing latency of the node, in seconds.

This property reflects the delay between when an impulse in the audio stream arrives at the input vs. output of the node. This should reflect the delay due to signal processing (e.g. filters, FFT’s, etc.), not delay or reverberation which is being applied as an effect. A value of zero indicates either no latency or an unknown latency.

pub fn output_presentation_latency(&self) -> TimeInterval

The maximum render pipeline latency downstream of the node, in seconds.

pub unsafe fn install_tap_on_bus_block_throws( &mut self, bus: AudioNodeBus, buffer_size: AudioFrameCount, format: Option<&AudioFormat>, tap_block: &mut Block<fn(&AudioPcmBuf, &AudioTime), Esc>, )

NOTE: remove_tap_on_bus if you have already installed tap

pub unsafe fn install_tap_on_bus_throws( &mut self, bus: AudioNodeBus, buffer_size: AudioFrameCount, format: Option<&AudioFormat>, tap_block: impl FnMut(&AudioPcmBuf, &AudioTime) + 'static, )

pub fn install_tap_on_bus<'ear>( &mut self, bus: AudioNodeBus, buffer_size: AudioFrameCount, format: Option<&AudioFormat>, tap_block: impl FnMut(&AudioPcmBuf, &AudioTime) + 'static, ) -> ExResult<'ear>

pub unsafe fn remove_tap_on_bus_throws(&mut self, bus: AudioNodeBus)

pub fn remove_tap_on_bus<'ear>(&mut self, bus: AudioNodeBus) -> ExResult<'ear>

Methods from Deref<Target = Id>

pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>

pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>

pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )

pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>

pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>

pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>

pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )

pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>

pub fn as_type_ref(&self) -> &Type

pub fn as_id_ref(&self) -> &Self

pub fn is_equal(&self, other: &Self) -> bool

pub fn hash(&self) -> UInteger

pub fn as_ptr(&self) -> *const Self