pub struct PlaybackSpeed(/* private fields */);Implementations
Sourceimpl PlaybackSpeed
impl PlaybackSpeed
pub fn cls() -> &'static Class<Self>
pub fn cls_ptr() -> *const c_void
pub fn alloc() -> A<Self>
pub fn with_playback_rate(rate: f32, localized_name: &String) -> R<Self>
pub fn rate(&self) -> f32
Sourcepub fn localized_name_ar(&self) -> Rar<String>
pub fn localized_name_ar(&self) -> Rar<String>
This name will be used to represent this playback speed in playback UIs where more space is available.
Sourcepub fn localized_name(&self) -> R<String>
pub fn localized_name(&self) -> R<String>
This name will be used to represent this playback speed in playback UIs where more space is available.
Sourcepub fn localized_numeric_name_ar(&self) -> Rar<String>
pub fn localized_numeric_name_ar(&self) -> Rar<String>
This name will be used to represent this playback speed in playback UIs where limited space is available.
Sourcepub fn localized_numeric_name(&self) -> R<String>
pub fn localized_numeric_name(&self) -> R<String>
This name will be used to represent this playback speed in playback UIs where limited space is available.
Methods from Deref<Target = Id>
pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>
pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>
pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )
pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>
pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>
pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>
pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )
pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>
pub fn as_type_ref(&self) -> &Type
pub fn as_id_ref(&self) -> &Self
pub fn is_equal(&self, other: &Self) -> bool
pub fn hash(&self) -> UInteger
pub fn as_ptr(&self) -> *const Self