#[repr(i32)]pub enum DisplayStreamUpdateRectType {
RefreshedRects = 0,
MovedRects = 1,
DirtyRects = 2,
ReducedDirtyRects = 3,
}Variants
RefreshedRects = 0
The rectangles that were refreshed on the display, not counting moved rectangles
MovedRects = 1
The rectangles that were simply moved from one part of the display to another
DirtyRects = 2
The union of both refreshed and moved rects
ReducedDirtyRects = 3
A possibly simplified (but overstated) array of dirty rectangles