ActivityType

Enum ActivityType 

#[repr(isize)]
pub enum ActivityType { Other = 1, AutomotiveNavigation = 2, Fitnes = 3, OtherNavigation = 4, Airborne = 5, }

Variants



Other = 1

positioning in activities that are not covered by one of the other activity types. Includes activities without a specific user intention; for example, positioning while the user sits on a bench interacting with the device



AutomotiveNavigation = 2

positioning in an automobile following a road network



Fitnes = 3

positioning in dedicated fitness sessions, e.g. walking workouts, running workouts, cycling workouts, etc.



OtherNavigation = 4

positioning for transportation that does not or may not adhere to roads such as cycling, scooters, trains, boats and off-road vehicles; also for positioning indoors and outdoors that isn’t tied to a dedicated fitness session, e.g. walking



Airborne = 5

positioning for activities in the air, e.g. flying in an airplane or helicopter, paragliding, flying on a drone, skydiving, etc. Also includes runway taxiing