RunStatus

Struct RunStatus 

#[repr(transparent)]
pub struct RunStatus(pub u32);

Tuple Fields

0: u32

Implementations

Source

impl Status

pub fn is_empty(&self) -> bool

pub fn any(&self, mask: Self) -> bool

pub fn contains(&self, val: Self) -> bool

pub fn insert(&mut self, val: Self)

pub fn remove(&mut self, val: Self)

pub fn set(&mut self, val: Self, on: bool)

Source

impl Status

pub const NO_STATUS: Self

The run has no special attributes.

pub const RIGHT_TO_LEFT: Self

When set, the run is right to left.

pub const NON_MONOTONIC: Self

When set, the run has been reordered in some way such that the string indices associated with the glyphs are no longer strictly increasing (for left to right runs) or decreasing (for right to left runs).

pub const HAS_NON_IDENTITY_MATRIX: Self

When set, the run requires a specific text matrix to be set in the current CG context for proper drawing.