pub struct ExecutionDesc(/* private fields */);Implementations
Sourceimpl ExecutionDesc
impl ExecutionDesc
Sourceimpl ExecutionDesc
impl ExecutionDesc
pub fn scheduled_handler(&self) -> Option<&ScheduledHandler>
pub fn set_scheduled_handler(&mut self, val: Option<&mut ScheduledHandler>)
pub fn completion_handler(&self) -> Option<&CompletionHandler>
pub fn set_completion_handler(&mut self, val: Option<&mut CompletionHandler>)
pub fn wait_until_completed(&self) -> bool
pub fn set_wait_until_completed(&mut self, val: bool)
pub fn compilation_desc_ar(&self) -> Option<Rar<CompilationDesc>>
Sourcepub fn sel_compilation_desc() -> &'static Sel
pub fn sel_compilation_desc() -> &'static Sel
@selector(compilationDescriptor) but dynamic
use this function to check if object responds to selector
pub fn compilation_desc(&self) -> Option<R<CompilationDesc>>
pub fn set_compilation_desc(&mut self, val: Option<&CompilationDesc>)
Sourcepub fn sel_set_compilation_desc() -> &'static Sel
pub fn sel_set_compilation_desc() -> &'static Sel
@selector(setCompilationDescriptor:) but dynamic
use this function to check if object responds to selector
Methods from Deref<Target = Id>
pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>
pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>
pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )
pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>
pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>
pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>
pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )
pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>
pub fn as_type_ref(&self) -> &Type
pub fn as_id_ref(&self) -> &Self
pub fn is_equal(&self, other: &Self) -> bool
pub fn hash(&self) -> UInteger
pub fn as_ptr(&self) -> *const Self