pub struct SpatialScaleDesc(/* private fields */);Implementations
Sourceimpl SpatialScaleDesc
impl SpatialScaleDesc
pub fn color_texture_format(&self) -> PixelFormat
pub fn set_color_texture_format(&mut self, val: PixelFormat)
pub fn output_texture_format(&self) -> PixelFormat
pub fn set_output_texture_format(&mut self, val: PixelFormat)
pub fn input_width(&self) -> usize
pub fn set_input_width(&mut self, val: usize)
pub fn input_height(&self) -> usize
pub fn set_input_height(&mut self, val: usize)
pub fn output_width(&self) -> usize
pub fn set_output_width(&mut self, val: usize)
pub fn output_height(&self) -> usize
pub fn set_output_height(&mut self, val: usize)
pub fn color_processing_mode(&self) -> SpatialScalerColorProcessingMode
pub fn set_color_processing_mode( &mut self, val: SpatialScalerColorProcessingMode, )
pub fn new_spatial_scaler(&self, device: &Device) -> Option<R<SpatialScaler>>
Sourcepub fn sel_new_spatial_scaler_with_compiler() -> &'static Sel
pub fn sel_new_spatial_scaler_with_compiler() -> &'static Sel
@selector(newSpatialScalerWithDevice:compiler:) but dynamic
use this function to check if object responds to selector
pub unsafe fn new_spatial_scaler_with_compiler( &self, device: &Device, compiler: &Compiler, ) -> Option<R<SpatialScaler>>
Sourcepub fn sel_supports_metal4_fx() -> &'static Sel
pub fn sel_supports_metal4_fx() -> &'static Sel
@selector(supportsMetal4FX:) but dynamic
use this function to check if object responds to selector
pub unsafe fn supports_metal4_fx(device: &Device) -> bool
pub fn supports_device(device: &Device) -> bool
Methods from Deref<Target = Id>
pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>
pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>
pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )
pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>
pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>
pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>
pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )
pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>
pub fn as_type_ref(&self) -> &Type
pub fn as_id_ref(&self) -> &Self
pub fn is_equal(&self, other: &Self) -> bool
pub fn hash(&self) -> UInteger
pub fn as_ptr(&self) -> *const Self