DecodingFailurePolicy

Enum DecodingFailurePolicy 

#[repr(isize)]
pub enum DecodingFailurePolicy { RaiseException = 0, SetErrorAndReturn = 1, }
Describes the action an ns::Coder should take when it encounters decode failures (e.g. corrupt data) for non-TopLevel decodes.

Variants



RaiseException = 0

On decode failure, the ns::Coder will raise an exception internally to propagate failure messages (and unwind the stack). This exception can be transformed into an ns::Error via any of the TopLevel decode APIs.



SetErrorAndReturn = 1

On decode failure, the ns::Coder will capture the failure as an ns::Error, and prevent further decodes (by returning 0 / None equivalent as appropriate). Clients should consider using this policy if they know that all encoded objects behave correctly in the presence of decode failures (e.g. they use fail_with_error to communicate decode failures and don’t raise exceptions for error propagation)