BlockOp

Struct BlockOp 

pub struct BlockOp(/* private fields */);

Implementations

Source

impl BlockOp

pub fn retained(&self) -> R<Self>

Source

impl BlockOp

pub fn cls() -> &'static Class<Self>

pub fn cls_ptr() -> *const c_void

pub fn alloc() -> A<Self>

pub fn with_block_ar(block: &mut WorkBlock) -> Rar<Self>

pub fn with_block(block: &mut WorkBlock) -> R<Self>

Methods from Deref<Target = Op>

pub fn retained(&self) -> R<Self>

pub fn is_cancelled(&self) -> bool

pub fn cancel(&mut self)

pub fn is_executing(&self) -> bool

A bool value indicating whether the operation is currently executing.

pub fn is_finished(&self) -> bool

pub fn is_ready(&self) -> bool

pub fn add_dependency(&mut self, val: &Op)

Makes the receiver dependent on the completion of the specified operation.

The receiver is not considered ready to execute until all of its dependent operations have finished executing. If the receiver is already executing its task, adding dependencies has no practical effect. This method may change the isReady and dependencies properties of the receiver.

It is a programmer error to create any circular dependencies among a set of operations. Doing so can cause a deadlock among the operations and may freeze your program.

pub fn remove_dependency(&mut self, val: &Op)

Removes the receiver’s dependence on the specified operation.

pub fn dependencies_ar(&self) -> Rar<Array<Op>>

An array of the operation objects that must finish executing before the current object can begin executing.

pub fn dependencies(&self) -> R<Array<Op>>

An array of the operation objects that must finish executing before the current object can begin executing.

pub fn name_ar(&self) -> Option<Rar<String>>

pub fn name(&self) -> Option<R<String>>

pub fn set_name(&mut self, val: Option<&String>)

pub fn start(&mut self)

Begins the execution of the operation.

pub fn main(&mut self)

Performs the receiver’s non-concurrent task.

Methods from Deref<Target = Id>

pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>

pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>

pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )

pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>

pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>

pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>

pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )

pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>

pub fn as_type_ref(&self) -> &Type

pub fn as_id_ref(&self) -> &Self

pub fn is_equal(&self, other: &Self) -> bool

pub fn hash(&self) -> UInteger

pub fn as_ptr(&self) -> *const Self