Data

Struct Data 

pub struct Data(/* private fields */);

Implementations

Source

impl Data

pub fn retained(&self) -> R<Self>

Source

impl Data

pub fn cls() -> &'static Class<Self>

pub fn cls_ptr() -> *const c_void

pub fn alloc() -> A<Self>

pub fn new() -> R<Data>

shortcut to Self::alloc().init()

Source

impl Data

pub fn with_contents_of_file<'ear, P: AsRef<String>>( path: P, options: ReadOpts, ) -> Result<R<Self>, &'ear Error>

pub fn with_contents_of_url<'ear, U: AsRef<Url>>( url: U, options: ReadOpts, ) -> Result<R<Self>, &'ear Error>

pub fn with_bytes(bytes: &[u8]) -> R<Self>

pub fn bytes(&self) -> *const u8

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn as_slice(&self) -> &[u8]

pub fn get_bytes(&self, buffer: *mut u8, length: usize)

pub fn get_bytes_range(&self, buffer: *mut u8, range: Range)

pub fn write_to_file(&self, path: &String, atomically: bool) -> bool

Writes the contents of the receiver to the file specified by a given path.

Writes the contents of the receiver to the file specified by path (overwriting any existing file at path). path is written in the default C-string encoding if possible (that is, if no information would be lost), in the Unicode encoding otherwise.

If flag is YES, the receiver is written to an auxiliary file, and then the auxiliary file is renamed to path. If flag is NO, the receiver is written directly to path. The YES option guarantees that path, if it exists at all, won’t be corrupted even if the system should crash during writing.

If path contains a tilde (~) character, you must expand it with stringByExpandingTildeInPath before invoking this method.

pub fn write_at_path(&self, path: &String, atomically: bool) -> Result<(), ()>

pub fn as_cf(&self) -> &Data

Source

impl Data

NSExtendedData

pub fn enumerate_byte_ranges_using_block( &self, block: &mut NoEscBlock<fn(*const u8, Range, &mut bool)>, )

pub fn enum_ranges(&self, block: impl FnMut(*const u8, Range, &mut bool))

Methods from Deref<Target = Id>

pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>

pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>

pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )

pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>

pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>

pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>

pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )

pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>

pub fn as_type_ref(&self) -> &Type

pub fn as_id_ref(&self) -> &Self

pub fn is_equal(&self, other: &Self) -> bool

pub fn hash(&self) -> UInteger

pub fn as_ptr(&self) -> *const Self