pub struct FileAttrType(/* private fields */);Implementations
Sourceimpl FileAttrType
impl FileAttrType
pub fn directory() -> &'static Self
pub fn regular() -> &'static Self
pub fn symbolic_link() -> &'static Self
pub fn socket() -> &'static Self
pub fn character_special() -> &'static Self
pub fn block_special() -> &'static Self
pub fn unknown() -> &'static Self
Methods from Deref<Target = String>
pub fn retained(&self) -> R<Self>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn lowercased_ar(&self) -> Rar<Self>
pub fn lowercased(&self) -> R<Self>
pub fn to_i32(&self) -> i32
pub fn to_i64(&self) -> i64
pub fn to_f32(&self) -> f32
pub fn to_f64(&self) -> f64
pub fn to_bool(&self) -> bool
Sourcepub fn to_integer(&self) -> Integer
pub fn to_integer(&self) -> Integer
The ns::Integer value of the string.
The ns::Integer value of the string, assuming a decimal representation and skipping whitespace at the beginning of the string. This property is 0 if the string doesn’t begin with a valid decimal text representation of a number. This property uses formatting information stored in the non-localized value; use an ns::Scanner object for localized scanning of numeric values from a string.
pub fn copy_mut(&self) -> Retained<StringMut>
Sourcepub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
pub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.
Sourcepub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
pub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.
pub fn substring_with_range<'ear>( &self, range: Range, ) -> ExResult<'ear, R<Self>>
pub fn substring<'ear>(&self, range: Range<usize>) -> ExResult<'ear, R<String>>
pub fn c_string(&self, encoding: Encoding) -> *const i8
pub fn len_of_bytes(&self, encoding: Encoding) -> UInteger
pub unsafe fn utf8_chars_ar(&self) -> *const i8
pub fn as_cf(&self) -> &String
pub fn eq_ns_string(&self, other: &Self) -> bool
pub fn to_selector(&self) -> Option<&'static Sel>
pub fn to_class(&self) -> Option<&'static Class<Id>>
pub fn hash(&self) -> UInteger
pub fn path_components_ar(&self) -> Rar<Array<String>>
pub fn path_components(&self) -> R<Array<String>>
pub fn is_abs_path(&self) -> bool
pub fn last_path_component_ar(&self) -> Rar<String>
pub fn last_path_component(&self) -> R<String>
pub fn string_by_deleting_last_path_component_ar(&self) -> Rar<String>
pub fn string_by_deleting_last_path_component(&self) -> R<String>
pub fn string_by_appending_path_component_ar(&self, str: &String) -> Rar<String>
pub fn string_by_appending_path_component(&self, str: &String) -> R<String>
pub fn path_extension_ar(&self) -> Rar<String>
pub fn path_extension(&self) -> R<String>
pub fn string_by_deleting_path_extension_ar(&self) -> Rar<String>
pub fn string_by_deleting_path_extension(&self) -> R<String>
pub fn string_by_appending_path_extension_ar(&self, str: &String) -> Rar<String>
pub fn string_by_appending_path_extension(&self, str: &String) -> R<String>
pub fn string_by_abbreviating_with_tilde_in_path_ar(&self) -> Rar<String>
pub fn string_by_abbreviating_with_tilde_in_path(&self) -> R<String>
pub fn string_by_expanding_tilde_in_path_ar(&self) -> Rar<String>
pub fn string_by_expanding_tilde_in_path(&self) -> R<String>
Methods from Deref<Target = Id>
pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>
pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>
pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )
pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>
pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>
pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>
pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )
pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>
pub fn as_type_ref(&self) -> &Type
pub fn as_id_ref(&self) -> &Self
pub fn is_equal(&self, other: &Self) -> bool
pub fn hash(&self) -> UInteger
pub fn as_ptr(&self) -> *const Self