pub struct NotificationName(/* private fields */);Implementations
Sourceimpl NotificationName
impl NotificationName
Sourcepub fn av_player_item_time_jumped() -> &'static Self
pub fn av_player_item_time_jumped() -> &'static Self
A notification the system posts when a player item’s time changes discontinuously.
The notification’s object is the player item.
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_did_play_to_end_time() -> &'static Self
pub fn av_player_item_did_play_to_end_time() -> &'static Self
A notification the system posts when a player item plays to its end time.
The notification’s object is the item that finished playing.
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_failed_play_to_end_time() -> &'static Self
pub fn av_player_item_failed_play_to_end_time() -> &'static Self
A notification that the system posts when a player item fails to play to its end time.
The notification’s object is the player item that finished playing.
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_playback_stalled() -> &'static Self
pub fn av_player_item_playback_stalled() -> &'static Self
A notification the system posts when a player item media doesn’t arrive in time to continue playback.
The notification’s object is the player item whose playback is unable to continue due to network delays. Streaming-media playback continues after the player item retrieves a sufficient amount of data. File-based playback doesn’t continue.
Important
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_new_access_log_entry() -> &'static Self
pub fn av_player_item_new_access_log_entry() -> &'static Self
A notification the system posts when a player item adds a new entry to its access log.
The notification’s object is the player item.
Important
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_error_access_log_entry() -> &'static Self
pub fn av_player_item_error_access_log_entry() -> &'static Self
A notification the system posts when a player item adds a new entry to its error log.
The notification’s object is the player item
The system may post this notification on a thread other than the one you use to register the observer.
Sourcepub fn av_player_item_recommended_time_offset_from_live_did_change() -> &'static Self
pub fn av_player_item_recommended_time_offset_from_live_did_change() -> &'static Self
A notification the player item posts when its offset from the live time changes.
Register to observe notifications of this type to observe changes to the value of the recommended_time_offset_from_live property
Sourcepub fn av_player_item_media_selection_did_change() -> &'static Self
pub fn av_player_item_media_selection_did_change() -> &'static Self
A notification the player item posts when its media selection changes.
Sourceimpl NotificationName
impl NotificationName
pub fn av_player_rate_did_change() -> &'static NotificationName
Sourceimpl NotificationName
impl NotificationName
Sourcepub fn audio_app_input_mute_state_change() -> &'static Self
pub fn audio_app_input_mute_state_change() -> &'static Self
Availability
macos_14_0, ios_17_0, tvos_17_0, watchos_10_0, visionos_1_0, maccatalyst_17_0
Methods from Deref<Target = String>
pub fn retained(&self) -> R<Self>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn lowercased_ar(&self) -> Rar<Self>
pub fn lowercased(&self) -> R<Self>
pub fn to_i32(&self) -> i32
pub fn to_i64(&self) -> i64
pub fn to_f32(&self) -> f32
pub fn to_f64(&self) -> f64
pub fn to_bool(&self) -> bool
Sourcepub fn to_integer(&self) -> Integer
pub fn to_integer(&self) -> Integer
The ns::Integer value of the string.
The ns::Integer value of the string, assuming a decimal representation and skipping whitespace at the beginning of the string. This property is 0 if the string doesn’t begin with a valid decimal text representation of a number. This property uses formatting information stored in the non-localized value; use an ns::Scanner object for localized scanning of numeric values from a string.
pub fn copy_mut(&self) -> Retained<StringMut>
Sourcepub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
pub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.
Sourcepub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
pub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.
pub fn substring_with_range<'ear>( &self, range: Range, ) -> ExResult<'ear, R<Self>>
pub fn substring<'ear>(&self, range: Range<usize>) -> ExResult<'ear, R<String>>
pub fn c_string(&self, encoding: Encoding) -> *const i8
pub fn len_of_bytes(&self, encoding: Encoding) -> UInteger
pub unsafe fn utf8_chars_ar(&self) -> *const i8
pub fn as_cf(&self) -> &String
pub fn eq_ns_string(&self, other: &Self) -> bool
pub fn to_selector(&self) -> Option<&'static Sel>
pub fn to_class(&self) -> Option<&'static Class<Id>>
pub fn hash(&self) -> UInteger
pub fn path_components_ar(&self) -> Rar<Array<String>>
pub fn path_components(&self) -> R<Array<String>>
pub fn is_abs_path(&self) -> bool
pub fn last_path_component_ar(&self) -> Rar<String>
pub fn last_path_component(&self) -> R<String>
pub fn string_by_deleting_last_path_component_ar(&self) -> Rar<String>
pub fn string_by_deleting_last_path_component(&self) -> R<String>
pub fn string_by_appending_path_component_ar(&self, str: &String) -> Rar<String>
pub fn string_by_appending_path_component(&self, str: &String) -> R<String>
pub fn path_extension_ar(&self) -> Rar<String>
pub fn path_extension(&self) -> R<String>
pub fn string_by_deleting_path_extension_ar(&self) -> Rar<String>
pub fn string_by_deleting_path_extension(&self) -> R<String>
pub fn string_by_appending_path_extension_ar(&self, str: &String) -> Rar<String>
pub fn string_by_appending_path_extension(&self, str: &String) -> R<String>
pub fn string_by_abbreviating_with_tilde_in_path_ar(&self) -> Rar<String>
pub fn string_by_abbreviating_with_tilde_in_path(&self) -> R<String>
pub fn string_by_expanding_tilde_in_path_ar(&self) -> Rar<String>
pub fn string_by_expanding_tilde_in_path(&self) -> R<String>
Methods from Deref<Target = Id>
pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>
pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>
pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )
pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>
pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>
pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>
pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>
pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )
pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>
pub fn as_type_ref(&self) -> &Type
pub fn as_id_ref(&self) -> &Self
pub fn is_equal(&self, other: &Self) -> bool
pub fn hash(&self) -> UInteger
pub fn as_ptr(&self) -> *const Self