SplitViewController

Struct SplitViewController 

pub struct SplitViewController(/* private fields */);

Implementations

Source

impl SplitViewController

pub fn retained(&self) -> R<Self>

Source

impl SplitViewController

pub fn split_view_ar(&self) -> Rar<SplitView>

pub fn split_view(&self) -> R<SplitView>

pub fn set_split_view(&mut self, val: &SplitView)

pub fn split_view_items_ar(&self) -> Rar<Array<SplitViewItem>>

pub fn split_view_items(&self) -> R<Array<SplitViewItem>>

pub fn set_split_view_items(&mut self, val: &Array<SplitViewItem>)

pub fn insert_split_view_item_at(&mut self, val: &SplitViewItem, index: isize)

pub fn remove_split_view_item(&mut self, val: &SplitView)

pub fn split_view_item_for_vc_ar( &self, vc: &ViewController, ) -> Option<Rar<SplitViewItem>>

pub fn split_view_item_for_vc( &self, vc: &ViewController, ) -> Option<R<SplitViewItem>>

pub fn min_thickness_for_inline_sidebars(&self) -> Float

pub fn set_min_thickness_for_inline_sidebars(&mut self, val: Float)

pub fn view_did_load(&mut self)

pub fn split_view_can_collapse_subview( &self, split_view: &SplitView, subview: &View, ) -> bool

pub fn split_view_should_hide_divider_at( &self, split_view: &SplitView, divider_index: isize, ) -> bool

pub fn split_view_effective_rect_for_drawn_rect_of_divider_at( &self, split_view: &SplitView, proposed_effective_rect: Rect, draw_rect: Rect, divider_index: isize, ) -> Rect

pub fn split_view_additional_effective_rect_of_divider_at( &self, split_view: &SplitView, divider_index: isize, ) -> Rect

Source

impl SplitViewController

NSSplitViewControllerToggleSidebarAction

pub fn toggle_sidebar(&mut self, sender: Option<&Id>)

pub fn sel_toggle_sidebar() -> &'static Sel

@selector(toggleSidebar:) but dynamic use this function to check if object responds to selector

pub fn toggle_inspector(&mut self, sender: Option<&Id>)

pub fn sel_toggle_inspector() -> &'static Sel

@selector(toggleInspector:) but dynamic use this function to check if object responds to selector

Methods from Deref<Target = ViewController>

pub fn retained(&self) -> R<Self>

pub fn title_ar(&self) -> Option<Rar<String>>

pub fn title(&self) -> Option<R<String>>

pub fn set_title_string(&mut self, val: Option<&String>)

pub fn set_title<S: AsRef<String>>(&mut self, val: Option<&S>)

pub fn view_ar(&self) -> Rar<View>

pub fn view(&self) -> R<View>

pub fn set_view(&mut self, val: &View)

pub fn view_if_loaded_ar(&self) -> Option<Rar<View>>

pub fn view_if_loaded(&self) -> Option<R<View>>

pub fn load_view(&mut self)

pub fn load_view_if_needed(&mut self)

pub fn is_view_loaded(&self) -> bool

pub fn parent_vc_ar(&self) -> Option<Rar<ViewController>>

pub fn parent_vc(&self) -> Option<R<ViewController>>

pub fn child_vcs_ar(&self) -> Rar<Array<ViewController>>

pub fn child_vcs(&self) -> R<Array<ViewController>>

pub fn add_child_vc(&mut self, val: &ViewController)

pub fn remove_from_parent_vc(&mut self)

pub fn insert_child_vc_at(&mut self, val: &ViewController, index: usize)

pub fn remove_child_vc_at(&mut self, index: usize)

pub fn preferred_content_size_did_change_for_vc(&mut self, val: &ViewController)

pub fn view_will_transition_to_size(&mut self, val: Size)

Methods from Deref<Target = Responder>

pub fn retained(&self) -> R<Self>

Methods from Deref<Target = Id>

pub unsafe fn value_for_key_throws_ar(&self, key: &String) -> Option<Rar<Self>>

pub unsafe fn value_for_key_throws(&self, key: &String) -> Option<R<Self>>

pub fn value_for_key<'ear>( &self, key: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_throws( &mut self, val: Option<&Self>, key: &String, )

pub fn set_value_for_key<'ear>( &mut self, val: Option<&Self>, key: &String, ) -> ExResult<'ear>

pub unsafe fn value_for_key_path_throws_ar( &self, key_path: &String, ) -> Option<Rar<Self>>

pub unsafe fn value_for_key_path_throws( &self, key_path: &String, ) -> Option<R<Self>>

pub fn value_for_key_path<'ear>( &self, key_path: &String, ) -> ExResult<'ear, Option<R<Self>>>

pub unsafe fn set_value_for_key_path_throws( &mut self, val: Option<&Self>, key_path: &String, )

pub fn set_value_for_key_path<'ear>( &mut self, val: Option<&Self>, key_path: &String, ) -> ExResult<'ear>

pub fn as_type_ref(&self) -> &Type

pub fn as_id_ref(&self) -> &Self

pub fn is_equal(&self, other: &Self) -> bool

pub fn hash(&self) -> UInteger

pub fn as_ptr(&self) -> *const Self