#[repr(isize)]pub enum ErrorCode {
UnknownError = 1,
OpFailed = 2,
InvalidFormat = 3,
InvalidModel = 4,
InvalidFile = 5,
}Variants
UnknownError = 1
An error that represents a failure that no other error handles.
OpFailed = 2
An error that occurs when the framework fails to analyze audio.
InvalidFormat = 3
An error that indicates the audio data’s format isn’t valid.
InvalidModel = 4
An error that indicates the sound classifier’s underlying Core ML model is an invalid model type.
InvalidFile = 5
An error that indicates an audio file is invalid.