Flags

Struct Flags 

#[repr(transparent)]
pub struct Flags(pub u32);

Tuple Fields

0: u32

Implementations

Source

impl Flags

pub fn is_empty(&self) -> bool

pub fn any(&self, mask: Self) -> bool

pub fn contains(&self, val: Self) -> bool

pub fn insert(&mut self, val: Self)

pub fn remove(&mut self, val: Self)

pub fn set(&mut self, val: Self, on: bool)

Source

impl Flags

pub const NONE: Self

pub const LEAVE_ALPHA_UNCHANGED: Self

Operate on red, green and blue channels only. Alpha is copied from source to destination. For Interleaved formats only.

pub const COPY_IN_PLACE: Self

Copy edge pixels. Convolution Only.

pub const BG_COLOR_FILL: Self

Use the background color for missing pixels.

pub const EDGE_EXTEND: Self

Use the nearest pixel for missing pixels.

pub const DO_NOT_TILE: Self

Pass to turn off internal tiling and disable internal multithreading. Use this if you want to do your own tiling, or to use the Min/Max filters in place.

pub const HQ_RESAMPLING: Self

Use a higher quality, slower resampling filter for Geometry operations (shear, scale, rotate, affine transform, etc.)

pub const TRUNCATE_KERNEL: Self

Use only the part of the kernel that overlaps the image. For integer kernels, real_divisor = divisor * (sum of used kernel elements) / (sum of kernel elements). This should preserve image brightness at the edges. Convolution only.

pub const GET_TEMP_BUF_SIZE: Self

The function will return the number of bytes required for the temp buffer. If this value is negative, it is an error, per standard usage.

pub const PRINT_DIAGNOSTICS_TO_CONSOLE: Self

Some functions such as vImageConverter_CreateWithCGImageFormat have so many possible error conditions that developers may need more help than a simple error code to diagnose problems. When this flag is set and an error is encountered, an informative error message will be logged to the Apple System Logger (ASL). The output should be visible in Console.app.

pub const NO_ALLOCATE: Self

Pass this flag to prevent vImage from allocating additional storage.

pub const HDR_CONTENT: Self

Use methods that are HDR-aware, capable of providing correct results for input images with pixel values outside the otherwise limited (typically [-2,2]) range. This may be SLOWER.

pub const DO_NOT_CLAMP: Self

Pass to disable clamping is some conversions to floating point formats. Use this if the input data may describe values outside [0,1] which should be preserved.

pub const USE_FP16_ACCUMULATOR: Self

Use a lower precision, faster floating-point arithmetic for all internal computations when available. This applies to all functions operating on 16-bit half-precision floating-point pixels, Pixel_16F.