pub struct Allocated<T: Release + 'static>(/* private fields */);Implementations
Sourceimpl Allocated<AudioUnit>
impl Allocated<AudioUnit>
pub unsafe fn init_with_comp_desc_opts_err<'ear>( self, desc: ComponentDesc, opts: ComponentInstantiationOpts, err: *mut Option<&'ear Error>, ) -> Option<R<AudioUnit>>
pub unsafe fn init_with_comp_desc_err<'ear>( self, desc: ComponentDesc, err: *mut Option<&'ear Error>, ) -> Option<R<AudioUnit>>
Sourceimpl Allocated<SysZoomSlider>
impl Allocated<SysZoomSlider>
pub unsafe fn init_with_device_throws( self, device: &CaptureDevice, ) -> R<SysZoomSlider>
pub fn init_with_device<'ear>( self, device: &CaptureDevice, ) -> ExResult<'ear, R<SysZoomSlider>>
pub unsafe fn init_with_device_action_throws( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> R<SysZoomSlider>
pub fn init_with_device_action<'ear>( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> ExResult<'ear, R<SysZoomSlider>>
Sourceimpl Allocated<SysExposureBiasSlider>
impl Allocated<SysExposureBiasSlider>
pub unsafe fn init_with_device_throws( self, device: &CaptureDevice, ) -> R<SysExposureBiasSlider>
pub fn init_with_device<'ear>( self, device: &CaptureDevice, ) -> ExResult<'ear, R<SysExposureBiasSlider>>
pub unsafe fn init_with_device_action_throws( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> R<SysExposureBiasSlider>
pub fn init_with_device_action<'ear>( self, device: &CaptureDevice, action: &mut EscBlock<fn(video_zoom_factor: Float)>, ) -> ExResult<'ear, R<SysExposureBiasSlider>>
Sourceimpl Allocated<Slider>
impl Allocated<Slider>
pub unsafe fn init_with_range_throws( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, ) -> R<Slider>
pub fn init_with_range<'ear>( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, ) -> ExResult<'ear, R<Slider>>
pub unsafe fn init_with_range_step_throws( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, step: f32, ) -> R<Slider>
pub fn init_with_range_step<'ear>( self, localized_title: &String, symbol_name: &String, min_val: f32, max_val: f32, step: f32, ) -> ExResult<'ear, R<Slider>>
pub unsafe fn init_with_vals_throws( self, localized_title: &String, symbol_name: &String, vals: &Array<Number>, ) -> R<Slider>
pub fn init_with_vals<'ear>( self, localized_title: &String, symbol_name: &String, vals: &Array<Number>, ) -> ExResult<'ear, R<Slider>>
Sourceimpl Allocated<IndexPicker>
impl Allocated<IndexPicker>
pub unsafe fn init_with_indexes_n_throws( self, localized_title: &String, symbol_name: &String, n: isize, ) -> R<IndexPicker>
pub fn init_with_indexes_n<'ear>( self, localized_title: &String, symbol_name: &String, n: isize, ) -> ExResult<'ear, R<IndexPicker>>
pub unsafe fn init_with_indexes_titles_throws( self, localized_title: &String, symbol_name: &String, titles: &Array<String>, ) -> R<IndexPicker>
pub fn init_with_titles<'ear>( self, localized_title: &String, symbol_name: &String, titles: &Array<String>, ) -> ExResult<'ear, R<IndexPicker>>
Sourceimpl Allocated<RotationCoordinator>
impl Allocated<RotationCoordinator>
pub fn init_with_device_preview_layer( &self, device: &Device, preview_layer: Option<&Layer>, ) -> R<RotationCoordinator>
Sourceimpl Allocated<DeviceInput>
impl Allocated<DeviceInput>
pub fn init_with_device_err<'ear>( self, device: &CaptureDevice, error: *mut Option<&'ear Error>, ) -> Option<R<DeviceInput>>
Sourceimpl Allocated<MultiCamSession>
impl Allocated<MultiCamSession>
pub fn init(self) -> Retained<MultiCamSession>
Sourceimpl Allocated<Connection>
impl Allocated<Connection>
pub fn init_with_ports( self, input: &Array<CaptureInputPort>, output: &CaptureOutput, ) -> R<Connection>
pub fn init_with_port_preview_layer( self, input: &CaptureInputPort, layer: &CaptureVideoPreviewLayer, ) -> R<Connection>
Sourceimpl Allocated<MetadataOutput>
impl Allocated<MetadataOutput>
pub fn init(self) -> Retained<MetadataOutput>
Sourceimpl Allocated<VideoDataOutput>
impl Allocated<VideoDataOutput>
pub fn init(self) -> Retained<VideoDataOutput>
Sourceimpl Allocated<VideoPreviewLayer>
impl Allocated<VideoPreviewLayer>
pub fn init_with_session(self, session: &CaptureSession) -> R<VideoPreviewLayer>
pub fn init_with_session_no_connection( self, session: &CaptureSession, ) -> R<VideoPreviewLayer>
Sourceimpl Allocated<PhotoOutput>
impl Allocated<PhotoOutput>
pub fn init(self) -> Retained<PhotoOutput>
Sourceimpl Allocated<PhotoSettings>
impl Allocated<PhotoSettings>
pub fn init(self) -> Retained<PhotoSettings>
Sourceimpl Allocated<AudioDataOutput>
impl Allocated<AudioDataOutput>
pub fn init(self) -> Retained<AudioDataOutput>
Sourceimpl Allocated<ItemVideoOutput>
impl Allocated<ItemVideoOutput>
pub fn init_with_pixel_buf_attrs( self, pixel_buf_attrs: Option<Dictionary<String, Id>>, ) -> R<ItemVideoOutput>
pub fn init_with_output_settings( self, output_settings: Option<Dictionary<String, Id>>, ) -> R<ItemVideoOutput>
Sourceimpl Allocated<Player>
impl Allocated<Player>
pub fn init_with_url(self, url: &Url) -> R<Player>
pub unsafe fn init_with_player_item_throws( self, item: Option<&PlayerItem>, ) -> R<Player>
Sourceimpl Allocated<QueuePlayer>
impl Allocated<QueuePlayer>
pub fn init(self) -> Retained<QueuePlayer>
Sourceimpl Allocated<QueuePlayer>
impl Allocated<QueuePlayer>
pub unsafe fn init_with_items_throws( self, items: &Array<PlayerItem>, ) -> R<QueuePlayer>
Sourceimpl Allocated<PlayerLayer>
impl Allocated<PlayerLayer>
pub fn init(self) -> Retained<PlayerLayer>
Sourceimpl Allocated<ReaderTrackOutput>
impl Allocated<ReaderTrackOutput>
pub fn init_with_track_throws( self, track: &Track, output_settings: Option<&Dictionary<String, Id>>, ) -> R<ReaderTrackOutput>
Sourceimpl Allocated<WriterInput>
impl Allocated<WriterInput>
pub unsafe fn init_media_type_output_settings_throws( self, media_type: &MediaType, output_settings: Option<&Dictionary<String, Id>>, ) -> R<WriterInput>
pub unsafe fn with_media_type_output_settings_source_format_hint_throws( self, media_type: &MediaType, output_settings: Option<&Dictionary<String, Id>>, source_format_hint: Option<&FormatDesc>, ) -> R<WriterInput>
Sourceimpl Allocated<WriterInputPixelBufAdaptor>
impl Allocated<WriterInputPixelBufAdaptor>
pub unsafe fn init_with_asset_writer_input_throws( self, input: &WriterInput, src_pixel_buf_attrs: Option<Dictionary<String, Id>>, ) -> R<WriterInputPixelBufAdaptor>
Sourceimpl Allocated<ImageGenerator>
impl Allocated<ImageGenerator>
pub fn init_with_asset(self, asset: &Asset) -> R<ImageGenerator>
Sourceimpl Allocated<UrlAsset>
impl Allocated<UrlAsset>
pub fn init_with_url_opts( self, url: &Url, options: Option<&Dictionary<String, Id>>, ) -> Option<R<UrlAsset>>
Sourceimpl Allocated<Effect>
impl Allocated<Effect>
pub fn init_with_audio_component_desc( self, description: ComponentDesc, ) -> R<Effect>
Sourceimpl Allocated<UnitEq>
impl Allocated<UnitEq>
pub fn init_with_number_of_bands(self, number_of_bands: usize) -> R<UnitEq>
Sourceimpl Allocated<TimeEffect>
impl Allocated<TimeEffect>
pub fn init_with_audio_component_desc( self, description: ComponentDesc, ) -> R<TimeEffect>
Sourceimpl Allocated<InputParams>
impl Allocated<InputParams>
pub fn init(self) -> Retained<InputParams>
Sourceimpl Allocated<InputParamsMut>
impl Allocated<InputParamsMut>
pub fn init(self) -> Retained<InputParamsMut>
Sourceimpl Allocated<Time>
impl Allocated<Time>
pub fn init_with_audio_ts_sample_rate( self, ts: &AudioTimeStamp, sample_rate: f64, ) -> R<Time>
pub fn init_with_host_time(self, host_time: u64) -> R<Time>
pub fn init_with_host_time_sample_rate_at_rate( self, host_time: u64, sample_time: FramePos, at_rate: f64, ) -> R<Time>
pub fn init_with_sample_time_at_rate( self, time: FramePos, at_rate: f64, ) -> R<Time>
Sourceimpl Allocated<Player>
impl Allocated<Player>
pub unsafe fn init_with_url_err<'ear>( self, url: &Url, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>
pub unsafe fn init_with_data_err<'ear>( self, data: &Data, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>
pub unsafe fn init_with_url_hint_err<'ear>( self, url: &Url, hint: Option<&String>, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>
pub unsafe fn init_with_data_hint_err<'ear>( self, data: &Data, hint: Option<&String>, err: *mut Option<&'ear Error>, ) -> Option<R<Player>>
Sourceimpl Allocated<PlayerNode>
impl Allocated<PlayerNode>
pub fn init(self) -> Retained<PlayerNode>
Sourceimpl Allocated<PcmBuf>
impl Allocated<PcmBuf>
pub fn init_with_pcm_format_frame_capacity( self, format: &Format, frame_capacity: FrameCount, ) -> Option<R<PcmBuf>>
pub fn init_with_pcm_format_buf_list_no_copy<const N: usize>( self, format: &Format, buf_list: &AudioBufList<N>, deallocator: Option<&mut EscBlock<fn(buf_list: *const AudioBufList<N>)>>, ) -> Option<R<PcmBuf>>
Sourceimpl Allocated<CompressedBuf>
impl Allocated<CompressedBuf>
pub fn init_with_format_and_packet_capacity( self, format: &Format, packet_capacity: PacketCount, ) -> R<CompressedBuf>
pub fn init_with_format_packet_capacity_and_maximum_packet_size( self, format: &Format, packet_capacity: PacketCount, maximum_packet_size: isize, ) -> R<CompressedBuf>
Sourceimpl Allocated<Format>
impl Allocated<Format>
pub fn init_with_stream_desc(self, asbd: &StreamBasicDesc) -> Option<R<Format>>
pub fn init_with_stream_desc_channel_layout( self, asbd: &StreamBasicDesc, layout: Option<&ChannelLayout>, ) -> Option<R<Format>>
pub fn init_standard_with_sample_rate_channels_ar( self, sample_rate: f64, channels: ChannelCount, ) -> Option<Rar<Format>>
pub fn init_standard_with_sample_rate_channels( self, sample_rate: f64, channels: ChannelCount, ) -> Option<R<Format>>
pub fn init_standard_with_sample_rate_channel_layout_ar( self, sample_rate: f64, layout: &ChannelLayout, ) -> Rar<Format>
pub fn init_standard_with_sample_rate_channel_layout( self, sample_rate: f64, layout: &ChannelLayout, ) -> R<Format>
pub fn init_with_common_format_sample_rate_channels_interleaved( self, format: CommonFormat, sample_rate: f64, channels: ChannelCount, interleaved: bool, ) -> Option<R<Format>>
pub fn init_with_common_format_sample_rate_interleaved_channel_layout( self, format: CommonFormat, sample_rate: f64, interleaved: bool, channel_layout: &ChannelLayout, ) -> R<Format>
pub fn init_with_settings( self, settings: &Dictionary<String, Id>, ) -> Option<R<Format>>
Sourceimpl Allocated<File>
impl Allocated<File>
pub unsafe fn init_for_reading_err_ar<'ear>( self, file_url: &Url, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>
pub unsafe fn init_for_reading_err<'ear>( self, file_url: &Url, err: *mut Option<&'ear Error>, ) -> Option<R<File>>
pub unsafe fn init_for_reading_common_format_err_ar<'ear>( self, file_url: &Url, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>
pub unsafe fn init_for_reading_common_format_err<'ear>( self, file_url: &Url, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<R<File>>
pub unsafe fn init_for_writing_err_ar<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>
pub unsafe fn init_for_writing_err<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<File>>
pub unsafe fn init_for_writing_common_format_err_ar<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<Rar<File>>
pub unsafe fn init_for_writing_common_format_err<'ear>( self, file_url: &Url, settings: &Dictionary<String, Id>, common_format: CommonFormat, interleaved: bool, err: *mut Option<&'ear Error>, ) -> Option<R<File>>
Sourceimpl Allocated<ChannelLayout>
impl Allocated<ChannelLayout>
pub fn init_with_layout<const N: usize>( self, layout: &AudioChannelLayout<N>, ) -> R<ChannelLayout>
pub fn init_with_layout_tag( self, tag: AudioChannelLayoutTag, ) -> R<ChannelLayout>
Sourceimpl Allocated<ConnectionPoint>
impl Allocated<ConnectionPoint>
pub fn init_with_node_bus(self, node: &Node, bus: NodeBus) -> R<ConnectionPoint>
Sourceimpl Allocated<Converter>
impl Allocated<Converter>
pub fn init_from_format_to_format_ar( self, from: &AudioFormat, to: &AudioFormat, ) -> Option<Rar<Converter>>
pub fn init_from_format_to_format( self, from: &AudioFormat, to: &AudioFormat, ) -> Option<R<Converter>>
Sourceimpl Allocated<Utterance>
impl Allocated<Utterance>
pub fn init_with_string(self, val: &String) -> R<Utterance>
pub fn init_with_attr_string(self, val: &AttrString) -> R<Utterance>
pub fn init_with_ssml(self, val: &String) -> R<Utterance>
Sourceimpl Allocated<Synthesizer>
impl Allocated<Synthesizer>
pub fn init(self) -> Retained<Synthesizer>
Sourceimpl Allocated<DisplayLayer>
impl Allocated<DisplayLayer>
pub fn init(self) -> Retained<DisplayLayer>
Sourceimpl Allocated<VideoRenderer>
impl Allocated<VideoRenderer>
pub fn init(self) -> Retained<VideoRenderer>
Sourceimpl Allocated<PipController>
impl Allocated<PipController>
pub fn init_with_content_src( self, content_src: &PipControllerContentSrc, ) -> R<PipController>
Sourcepub fn sel_init_with_content_src() -> &'static Sel
pub fn sel_init_with_content_src() -> &'static Sel
@selector(initWithContentSource:) but dynamic
use this function to check if object responds to selector
pub fn init_with_player_layer( self, player_layer: &PlayerLayer, ) -> Option<R<PipController>>
Sourceimpl Allocated<PipControllerContentSrc>
impl Allocated<PipControllerContentSrc>
pub fn init_with_player_layer( self, player_layer: &PlayerLayer, ) -> R<PipControllerContentSrc>
Sourcepub fn sel_init_with_player_layer() -> &'static Sel
pub fn sel_init_with_player_layer() -> &'static Sel
@selector(initWithPlayerLayer:) but dynamic
use this function to check if object responds to selector
Sourceimpl Allocated<PipControllerContentSrc>
impl Allocated<PipControllerContentSrc>
pub fn init_with_sample_buf_display_layer<D: PipSampleBufPlayerDelegate>( self, sbuf_display_layer: &SampleBufDisplayLayer, playback_delegate: &D, ) -> R<PipControllerContentSrc>
Sourceimpl Allocated<PlaybackSpeed>
impl Allocated<PlaybackSpeed>
pub fn init_with_rate( self, rate: f32, localized_name: &String, ) -> R<PlaybackSpeed>
Sourceimpl Allocated<DisplayLink>
impl Allocated<DisplayLink>
pub fn init(self) -> Retained<DisplayLink>
Sourceimpl Allocated<MediaTimingFn>
impl Allocated<MediaTimingFn>
pub fn init_with_ctrl_points( self, c1x: f32, c1y: f32, c2x: f32, c2y: f32, ) -> R<MediaTimingFn>
Sourceimpl Allocated<MetalLayer>
impl Allocated<MetalLayer>
pub fn init(self) -> Retained<MetalLayer>
Sourceimpl Allocated<Transaction>
impl Allocated<Transaction>
pub fn init(self) -> Retained<Transaction>
Sourceimpl Allocated<Context>
impl Allocated<Context>
pub fn init_with_opts( self, options: Option<&Dictionary<String, Id>>, ) -> Option<R<Context>>
Sourceimpl Allocated<Image>
impl Allocated<Image>
pub fn init_with_mlt_texture_options( self, texture: &Texture, options: Option<&DictionaryOf<ImageOpt, Type>>, ) -> Option<Retained<Image>>
pub fn init_with_cv_image_buf_options( self, image_buf: &ImageBuf, options: Option<&DictionaryOf<ImageOpt, Type>>, ) -> Option<Retained<Image>>
pub fn init_with_cv_pixel_buf_options( self, pixel_buf: &PixelBuf, options: Option<&DictionaryOf<ImageOpt, Type>>, ) -> Option<Retained<Image>>
Sourceimpl Allocated<LocationManager>
impl Allocated<LocationManager>
pub fn init(self) -> Retained<LocationManager>
Sourceimpl Allocated<Location>
impl Allocated<Location>
pub fn init_with_lat_lon( self, lat: LocationDegrees, lon: LocationDegrees, ) -> R<Location>
Sourceimpl Allocated<TapDesc>
impl Allocated<TapDesc>
pub fn init_stereo_mixdown_of_processes_ar( self, processes_obj_ids_to_include: &Array<Number>, ) -> Rar<TapDesc>
pub fn init_stereo_mixdown_of_processes( self, processes_obj_ids_to_include: &Array<Number>, ) -> R<TapDesc>
pub fn init_stereo_global_tap_but_exclude_processes_ar( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> Rar<TapDesc>
pub fn init_stereo_global_tap_but_exclude_processes( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> R<TapDesc>
pub fn init_mono_mixdown_of_processes_ar( self, processes_obj_ids_to_include: &Array<Number>, ) -> Rar<TapDesc>
pub fn init_mono_mixdown_of_processes( self, processes_obj_ids_to_include: &Array<Number>, ) -> R<TapDesc>
pub fn init_mono_global_tap_but_exclude_processes_ar( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> Rar<TapDesc>
pub fn init_mono_global_tap_but_exclude_processes( self, processes_obj_ids_to_exclude: &Array<Number>, ) -> R<TapDesc>
pub fn init_with_processes_and_device( self, processes_obj_ids_to_include: &Array<Number>, device_uid: &String, stream: isize, ) -> R<TapDesc>
pub fn init_excluding_processes_and_device_ar( self, processes_obj_ids_to_exclude: &Array<Number>, device_uid: &String, stream: isize, ) -> Rar<TapDesc>
pub fn init_excluding_processes_and_device( self, processes_obj_ids_to_exclude: &Array<Number>, device_uid: &String, stream: isize, ) -> R<TapDesc>
Sourceimpl Allocated<HeadphoneMotionManager>
impl Allocated<HeadphoneMotionManager>
pub fn init(self) -> Retained<HeadphoneMotionManager>
Sourceimpl Allocated<MotionManager>
impl Allocated<MotionManager>
pub fn init(self) -> Retained<MotionManager>
Sourceimpl Allocated<BrowserViewController>
impl Allocated<BrowserViewController>
pub unsafe fn init_with_service_type_throws( self, service_type: &String, session: &Session, ) -> R<BrowserViewController>
pub unsafe fn init_with_browser_throws( self, browser: &NearbyServiceBrowser, session: &Session, ) -> R<BrowserViewController>
Sourceimpl Allocated<PeerId>
impl Allocated<PeerId>
pub unsafe fn init_with_display_name_throws( self, display_name: &String, ) -> R<PeerId>
Sourceimpl Allocated<Session>
impl Allocated<Session>
pub unsafe fn init_with_peer_throws(self, peer: &PeerId) -> R<Session>
pub unsafe fn init_with_encryption_throws( self, peer: &PeerId, sec_identity: Option<&Array<Id>>, encryption_preference: EncryptionPreference, ) -> R<Session>
Sourceimpl Allocated<AdvertiserAssistant>
impl Allocated<AdvertiserAssistant>
pub unsafe fn init_service_type_throws_ar( self, peer: &PeerId, service_type: &String, ) -> Rar<AdvertiserAssistant>
pub unsafe fn init_service_type_throws( self, peer: &PeerId, service_type: &String, ) -> R<AdvertiserAssistant>
Sourceimpl Allocated<NearbyServiceAdvertiser>
impl Allocated<NearbyServiceAdvertiser>
pub unsafe fn init_with_peer_throws( self, my_peer: &PeerId, discorvery_info: Option<&Dictionary<String, String>>, service_type: &String, ) -> R<NearbyServiceAdvertiser>
Sourceimpl Allocated<NearbyServiceBrowser>
impl Allocated<NearbyServiceBrowser>
pub unsafe fn init_with_peer_and_service_type_throws( self, peer: &PeerId, service_type: &String, ) -> R<NearbyServiceBrowser>
Sourceimpl Allocated<GeometryDesc>
impl Allocated<GeometryDesc>
pub fn init(self) -> Retained<GeometryDesc>
Sourceimpl Allocated<MotionBoundingBoxGeometryDesc>
impl Allocated<MotionBoundingBoxGeometryDesc>
pub fn init(self) -> Retained<MotionBoundingBoxGeometryDesc>
Sourceimpl Allocated<TensorExtents>
impl Allocated<TensorExtents>
pub fn init(self) -> Retained<TensorExtents>
Sourceimpl Allocated<TensorExtents>
impl Allocated<TensorExtents>
Sourcepub fn sel_init_with_rank() -> &'static Sel
pub fn sel_init_with_rank() -> &'static Sel
@selector(initWithRank:values:) but dynamic
use this function to check if object responds to selector
pub unsafe fn init_with_rank( self, rank: usize, values: *const usize, ) -> Option<R<TensorExtents>>
Sourceimpl Allocated<TensorDesc>
impl Allocated<TensorDesc>
pub fn init(self) -> Retained<TensorDesc>
Sourceimpl Allocated<ResidencySetDesc>
impl Allocated<ResidencySetDesc>
pub fn init(self) -> Retained<ResidencySetDesc>
Sourceimpl Allocated<CompileOpts>
impl Allocated<CompileOpts>
pub fn init(self) -> Retained<CompileOpts>
Sourceimpl Allocated<FnConstValues>
impl Allocated<FnConstValues>
pub fn init(self) -> Retained<FnConstValues>
Sourceimpl Allocated<FnStitchingAttrAlwaysInline>
impl Allocated<FnStitchingAttrAlwaysInline>
pub fn init(self) -> Retained<FnStitchingAttrAlwaysInline>
Sourceimpl Allocated<FnStitchingInputNode>
impl Allocated<FnStitchingInputNode>
pub fn init(self) -> Retained<FnStitchingInputNode>
Sourceimpl Allocated<FnStitchingInputNode>
impl Allocated<FnStitchingInputNode>
pub fn init_with_arg_index(self, index: usize) -> R<FnStitchingInputNode>
Sourceimpl Allocated<FnStitchingFnNode>
impl Allocated<FnStitchingFnNode>
pub fn init_with_name( self, name: &String, args: &Array<FnStitchingNode>, control_deps: &Array<FnStitchingFnNode>, ) -> R<FnStitchingFnNode>
Sourceimpl Allocated<FnStitchingGraph>
impl Allocated<FnStitchingGraph>
pub fn init_with_fn_name( self, fn_name: &String, nodes: &Array<FnStitchingFnNode>, output_node: Option<&FnStitchingFnNode>, attribtues: &Array<FnStitchingAttr>, ) -> R<FnStitchingGraph>
Sourceimpl Allocated<FnStitchedLibDesc>
impl Allocated<FnStitchedLibDesc>
pub fn init(self) -> Retained<FnStitchedLibDesc>
Sourceimpl Allocated<TileRenderPipelineDesc>
impl Allocated<TileRenderPipelineDesc>
pub fn init(self) -> Retained<TileRenderPipelineDesc>
pub fn init_with_dispatch_queue(self, queue: &Queue) -> R<SharedEventListener>
Sourceimpl Allocated<StencilDesc>
impl Allocated<StencilDesc>
pub fn init(self) -> Retained<StencilDesc>
Sourceimpl Allocated<DepthStencilDesc>
impl Allocated<DepthStencilDesc>
pub fn init(self) -> Retained<DepthStencilDesc>
Sourceimpl Allocated<VertexBufLayoutDesc>
impl Allocated<VertexBufLayoutDesc>
pub fn init(self) -> Retained<VertexBufLayoutDesc>
Sourceimpl Allocated<VertexAttrDesc>
impl Allocated<VertexAttrDesc>
pub fn init(self) -> Retained<VertexAttrDesc>
Sourceimpl Allocated<PipelineBufDesc>
impl Allocated<PipelineBufDesc>
pub fn init(self) -> Retained<PipelineBufDesc>
Sourceimpl Allocated<CaptureDesc>
impl Allocated<CaptureDesc>
pub fn init(self) -> Retained<CaptureDesc>
Sourceimpl Allocated<FrameInterpolatorDesc>
impl Allocated<FrameInterpolatorDesc>
pub fn init(self) -> Retained<FrameInterpolatorDesc>
Sourceimpl Allocated<TemporalDenoisedScalerDesc>
impl Allocated<TemporalDenoisedScalerDesc>
pub fn init(self) -> Retained<TemporalDenoisedScalerDesc>
Sourceimpl Allocated<SpatialScaleDesc>
impl Allocated<SpatialScaleDesc>
pub fn init(self) -> Retained<SpatialScaleDesc>
Sourceimpl Allocated<ArgTableDesc>
impl Allocated<ArgTableDesc>
pub fn init(self) -> Retained<ArgTableDesc>
Sourceimpl Allocated<CounterHeapDesc>
impl Allocated<CounterHeapDesc>
pub fn init(self) -> Retained<CounterHeapDesc>
Sourceimpl Allocated<CmdAllocatorDesc>
impl Allocated<CmdAllocatorDesc>
pub fn init(self) -> Retained<CmdAllocatorDesc>
Sourceimpl Allocated<CmdBufOpts>
impl Allocated<CmdBufOpts>
pub fn init(self) -> Retained<CmdBufOpts>
Sourceimpl Allocated<CommitOpts>
impl Allocated<CommitOpts>
pub fn init(self) -> Retained<CommitOpts>
Sourceimpl Allocated<CmdQueueDesc>
impl Allocated<CmdQueueDesc>
pub fn init(self) -> Retained<CmdQueueDesc>
Sourceimpl Allocated<CompilerDesc>
impl Allocated<CompilerDesc>
pub fn init(self) -> Retained<CompilerDesc>
Sourceimpl Allocated<RenderPassDesc>
impl Allocated<RenderPassDesc>
pub fn init(self) -> Retained<RenderPassDesc>
Sourceimpl Allocated<MlPipelineDesc>
impl Allocated<MlPipelineDesc>
pub fn init(self) -> Retained<MlPipelineDesc>
Sourceimpl Allocated<PipelineOpts>
impl Allocated<PipelineOpts>
pub fn init(self) -> Retained<PipelineOpts>
Sourceimpl Allocated<TextureLoader>
impl Allocated<TextureLoader>
pub fn init_with_device(self, device: &Device) -> R<TextureLoader>
Sourceimpl Allocated<TrainingGraph>
impl Allocated<TrainingGraph>
pub fn init(self) -> Retained<TrainingGraph>
Sourceimpl Allocated<ExecutionDesc>
impl Allocated<ExecutionDesc>
pub fn init(self) -> Retained<ExecutionDesc>
Sourceimpl Allocated<Executable>
impl Allocated<Executable>
pub fn init(self) -> Retained<Executable>
Sourceimpl Allocated<Executable>
impl Allocated<Executable>
pub fn init_with_mps_graph_package_at_url( self, mps_graph_package_url: &Url, compilation_descriptor: Option<&CompilationDesc>, ) -> R<Executable>
Sourcepub fn sel_init_with_mps_graph_package_at_url() -> &'static Sel
pub fn sel_init_with_mps_graph_package_at_url() -> &'static Sel
@selector(initWithMPSGraphPackageAtURL:compilationDescriptor:) but dynamic
use this function to check if object responds to selector
pub fn init_with_core_ml_package_at_url( self, core_ml_package_url: &Url, compilation_descriptor: Option<&CompilationDesc>, ) -> R<Executable>
Sourcepub fn sel_init_with_core_ml_package_at_url() -> &'static Sel
pub fn sel_init_with_core_ml_package_at_url() -> &'static Sel
@selector(initWithCoreMLPackageAtURL:compilationDescriptor:) but dynamic
use this function to check if object responds to selector
Sourceimpl Allocated<TensorData>
impl Allocated<TensorData>
pub fn init(self) -> Retained<TensorData>
Sourceimpl Allocated<TensorData>
impl Allocated<TensorData>
pub fn init_with_device_data_shape_data_type( self, device: &Device, data: &Data, shape: &Shape, data_type: DType, ) -> R<TensorData>
pub fn init_with_mtl_buffer_shape_data_type( self, buffer: &Buf, shape: &Shape, data_type: DType, ) -> R<TensorData>
pub fn init_with_mtl_buffer_shape_data_type_row_bytes( self, buffer: &Buf, shape: &Shape, data_type: DType, row_bytes: usize, ) -> R<TensorData>
Sourcepub fn sel_init_with_mtl_buffer_shape_data_type_row_bytes() -> &'static Sel
pub fn sel_init_with_mtl_buffer_shape_data_type_row_bytes() -> &'static Sel
@selector(initWithMTLBuffer:shape:dataType:rowBytes:) but dynamic
use this function to check if object responds to selector
pub fn init_with_mps_nd_array(self, ndarray: &NdArray) -> R<TensorData>
Sourceimpl Allocated<SingleGateRnnDesc>
impl Allocated<SingleGateRnnDesc>
pub fn init(self) -> Retained<SingleGateRnnDesc>
Sourceimpl Allocated<CompilationDesc>
impl Allocated<CompilationDesc>
pub fn init(self) -> Retained<CompilationDesc>
Sourceimpl Allocated<ExecutionDesc>
impl Allocated<ExecutionDesc>
pub fn init(self) -> Retained<ExecutionDesc>
Sourceimpl Allocated<ArrayBatchProvider>
impl Allocated<ArrayBatchProvider>
pub fn init_with_feature_provider_array<P: FeatureProvider>( self, arr: &Array<P>, ) -> R<ArrayBatchProvider>
pub unsafe fn init_with_dictionary<'ear>( self, dictionary: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<ArrayBatchProvider>>
Sourceimpl Allocated<DictionaryFeatureProvider>
impl Allocated<DictionaryFeatureProvider>
pub unsafe fn init_with_dictionary_err<'ear>( self, dictionary: &Dictionary<String, Id>, err: *mut Option<&'ear Error>, ) -> Option<R<DictionaryFeatureProvider>>
Sourceimpl Allocated<FeatureValue>
impl Allocated<FeatureValue>
pub fn init(self) -> Retained<FeatureValue>
Sourceimpl Allocated<MultiArray>
impl Allocated<MultiArray>
pub fn init(self) -> Retained<MultiArray>
Sourceimpl Allocated<MultiArray>
impl Allocated<MultiArray>
pub unsafe fn init_with_shape_err<'ear>( self, shape: &Array<Number>, d_type: MultiArrayDType, err: *mut Option<&'ear Error>, ) -> Option<R<MultiArray>>
pub fn init_with_shape_strides( self, shape: &Array<Number>, d_type: MultiArrayDType, strides: &Array<Number>, ) -> R<MultiArray>
pub unsafe fn init_with_ptr<'ear>( self, data_ptr: *mut c_void, shape: &Array<Number>, d_type: MultiArrayDType, strides: &Array<Number>, deallocator: Option<&mut EscBlock<fn(ptr: *mut c_void)>>, error: *mut Option<&'ear Error>, ) -> Option<R<MultiArray>>
pub unsafe fn init_with_pixel_buf_throws( self, pixel_buf: &PixelBuf, shape: &Array<Number>, ) -> R<MultiArray>
Sourceimpl Allocated<PredictionOpts>
impl Allocated<PredictionOpts>
pub fn init(self) -> Retained<PredictionOpts>
Sourceimpl Allocated<DateFormatter>
impl Allocated<DateFormatter>
pub fn init(self) -> Retained<DateFormatter>
Sourceimpl Allocated<Iso8601DateFormatter>
impl Allocated<Iso8601DateFormatter>
pub fn init(self) -> Retained<Iso8601DateFormatter>
Sourceimpl Allocated<UrlRequest>
impl Allocated<UrlRequest>
pub fn init_with_url(self, url: &Url) -> R<UrlRequest>
pub fn init_with_url_cache_policy_timeout( self, url: &Url, cache_policy: CachePolicy, timeout: TimeInterval, ) -> R<UrlRequest>
Sourceimpl Allocated<UrlRequestMut>
impl Allocated<UrlRequestMut>
pub fn init_with_url(self, url: &Url) -> R<UrlRequestMut>
pub fn init_with_url_cache_policy_timeout( self, url: &Url, cache_policy: CachePolicy, timeout: TimeInterval, ) -> R<UrlRequestMut>
Sourceimpl Allocated<WebSocketMessage>
impl Allocated<WebSocketMessage>
pub fn init_with_data(self, data: &Data) -> R<WebSocketMessage>
pub fn init_with_string(self, string: &String) -> R<WebSocketMessage>
Sourceimpl Allocated<UserActivity>
impl Allocated<UserActivity>
pub fn init_with_activity_type(self, activity_type: &String) -> R<UserActivity>
Sourceimpl Allocated<UserDefaults>
impl Allocated<UserDefaults>
pub fn init(self) -> Retained<UserDefaults>
Sourceimpl Allocated<UserDefaults>
impl Allocated<UserDefaults>
pub fn init_with_suite_name( self, name: Option<&String>, ) -> Option<R<UserDefaults>>
Sourceimpl Allocated<IndexSet>
impl Allocated<IndexSet>
pub fn init_with_index(self, val: usize) -> R<IndexSet>
pub fn init_with_index_set(self, val: &IndexSet) -> R<IndexSet>
pub fn init_with_range(self, val: Range) -> R<IndexSet>
Sourceimpl Allocated<IndexSetMut>
impl Allocated<IndexSetMut>
pub fn init_with_index(self, val: usize) -> R<IndexSetMut>
pub fn init_with_index_set(self, val: &IndexSet) -> R<IndexSetMut>
pub fn init_with_range(self, val: Range) -> R<IndexSetMut>
Sourceimpl Allocated<IndexSetMut>
impl Allocated<IndexSetMut>
pub fn init(self) -> Retained<IndexSetMut>
Sourceimpl<K: Obj, V: Obj> Allocated<Dictionary<K, V>>
impl<K: Obj, V: Obj> Allocated<Dictionary<K, V>>
pub fn init_ar(self) -> Rar<Dictionary<K, V>>
pub fn init(self) -> R<Dictionary<K, V>>
pub unsafe fn init_with_objs_for_keys_count_throws( self, objects: *const V, keys: *const K, count: usize, ) -> R<Dictionary<K, V>>
Sourceimpl<K: Obj, V: Obj> Allocated<DictionaryMut<K, V>>
impl<K: Obj, V: Obj> Allocated<DictionaryMut<K, V>>
pub fn init_ar(self) -> Rar<DictionaryMut<K, V>>
pub fn init(self) -> R<DictionaryMut<K, V>>
pub fn init_with_capacity(self, capacity: usize) -> R<DictionaryMut<K, V>>
Sourceimpl Allocated<Data>
impl Allocated<Data>
pub fn init_with_contents_of_file_opts_err<'ear>( self, path: &String, options: ReadOpts, error: *mut Option<&'ear Error>, ) -> Option<R<Data>>
pub fn init_with_contents_of_url_opts_err<'ear>( self, url: &Url, options: ReadOpts, error: *mut Option<&'ear Error>, ) -> Option<R<Data>>
pub fn init_with_bytes(self, bytes: *const u8, length: usize) -> R<Data>
Sourceimpl Allocated<String>
impl Allocated<String>
pub fn init_with_bytes_length_encoding( self, bytes: *const u8, length: usize, encoding: StringEncoding, ) -> Option<R<String>>
pub fn init_with_bytes_no_copy_length_encoding_free_when_done( self, bytes: *const u8, length: usize, encoding: StringEncoding, free_when_done: bool, ) -> Option<R<String>>
Sourceimpl Allocated<AttrString>
impl Allocated<AttrString>
pub fn init(self) -> Retained<AttrString>
Sourceimpl Allocated<AttrString>
impl Allocated<AttrString>
pub fn init_with_string(self, str: &String) -> R<AttrString>
pub fn init_with_attr_string(self, str: &AttrString) -> R<AttrString>
Sourceimpl Allocated<AttrStringMut>
impl Allocated<AttrStringMut>
pub fn init(self) -> Retained<AttrStringMut>
Sourceimpl Allocated<AttrStringMut>
impl Allocated<AttrStringMut>
pub fn init_with_string(self, str: &String) -> R<AttrStringMut>
pub fn init_with_attr_string(self, str: &AttrString) -> R<AttrStringMut>
Sourceimpl Allocated<Url>
impl Allocated<Url>
pub fn init_with_path_is_dir_relative_to_url_ar( self, path: &String, is_dir: bool, relative_to: Option<&Url>, ) -> Rar<Url>
pub fn init_with_path_is_dir_relative_to_url( self, path: &String, is_dir: bool, relative_to: Option<&Url>, ) -> R<Url>
pub fn init_with_string_relative_to( self, string: &String, relative_to: Option<&Url>, ) -> Option<R<Url>>
Sourceimpl Allocated<Date>
impl Allocated<Date>
pub fn init_with_time_interval_since_now(self, secs: TimeInterval) -> R<Date>
pub fn init_with_time_interval_since_1970(self, secs: TimeInterval) -> R<Date>
Sourceimpl Allocated<Error>
impl Allocated<Error>
pub fn init_with_domain( self, domain: &ErrorDomain, code: Integer, user_info: Option<&Dictionary<String, Id>>, ) -> R<Error>
Sourceimpl Allocated<Timer>
impl Allocated<Timer>
pub fn init_with_fire_date_block( self, date: &Date, interval: TimeInterval, repeats: bool, block: &mut SyncBlock<fn(timer: &mut Timer)>, ) -> R<Timer>
pub fn init_with_fire_date_sel( self, date: &Date, interval: TimeInterval, target: &Id, selector: &Sel, user_info: Option<&Id>, repeats: bool, ) -> R<Timer>
Sourceimpl Allocated<Notification>
impl Allocated<Notification>
pub fn init_with_name( self, name: &NotificationName, object: Option<&Id>, user_info: Option<&Dictionary<Id, Id>>, ) -> R<Notification>
pub fn init_with_coder(self, coder: &Coder) -> R<Notification>
Sourceimpl Allocated<NotificationCenter>
impl Allocated<NotificationCenter>
pub fn init(self) -> Retained<NotificationCenter>
Sourceimpl<S: Obj, I: Obj> Allocated<DiffableDataSrcSnapshot<S, I>>
impl<S: Obj, I: Obj> Allocated<DiffableDataSrcSnapshot<S, I>>
pub fn init_ar(self) -> Rar<DiffableDataSrcSnapshot<S, I>>
pub fn init(self) -> R<DiffableDataSrcSnapshot<S, I>>
Sourceimpl<T: Obj> Allocated<OrderedCollectionChange<T>>
impl<T: Obj> Allocated<OrderedCollectionChange<T>>
pub fn init_with_object_type_index( self, object: Option<&T>, type_: CollectionChangeType, index: UInteger, ) -> R<OrderedCollectionChange<T>>
pub fn init_with_object_type_index_associated( self, object: Option<&T>, type_: CollectionChangeType, index: UInteger, associated_index: UInteger, ) -> R<OrderedCollectionChange<T>>
Sourceimpl<T: Obj> Allocated<OrderedCollectionDiff<T>>
impl<T: Obj> Allocated<OrderedCollectionDiff<T>>
pub fn init_with_changes( self, changes: &Array<OrderedCollectionChange<T>>, ) -> R<OrderedCollectionDiff<T>>
Sourceimpl Allocated<AnimationCtx>
impl Allocated<AnimationCtx>
pub fn init(self) -> Retained<AnimationCtx>
Sourceimpl Allocated<CollectionView>
impl Allocated<CollectionView>
pub fn init(self) -> Retained<CollectionView>
Sourceimpl Allocated<CollectionViewItem>
impl Allocated<CollectionViewItem>
pub fn init(self) -> Retained<CollectionViewItem>
Sourceimpl Allocated<ColorSpace>
impl Allocated<ColorSpace>
pub fn init(self) -> Retained<ColorSpace>
Sourceimpl Allocated<ColorSpace>
impl Allocated<ColorSpace>
pub fn init_with_cg_color_space(self, val: &ColorSpace) -> Option<R<ColorSpace>>
Sourceimpl<S: Obj, I: Obj> Allocated<CollectionViewDiffableDataSrc<S, I>>
impl<S: Obj, I: Obj> Allocated<CollectionViewDiffableDataSrc<S, I>>
pub fn init_with_collection_view_item_provider( self, collection_view: &CollectionView, item_provider: &mut CollectionViewDiffableDataSrcItemProvider<I>, ) -> R<CollectionViewDiffableDataSrc<S, I>>
Sourceimpl Allocated<FontManager>
impl Allocated<FontManager>
pub fn init(self) -> Retained<FontManager>
Sourceimpl Allocated<GestureRecognizer>
impl Allocated<GestureRecognizer>
pub fn init_with_target( self, target: Option<&Id>, action: Option<&Sel>, ) -> R<GestureRecognizer>
Sourceimpl Allocated<GestureRecognizer>
impl Allocated<GestureRecognizer>
pub fn init(self) -> Retained<GestureRecognizer>
Sourceimpl Allocated<Pasteboard>
impl Allocated<Pasteboard>
pub fn init(self) -> Retained<Pasteboard>
Sourceimpl Allocated<RunningApp>
impl Allocated<RunningApp>
pub fn init(self) -> Retained<RunningApp>
Sourceimpl Allocated<SplitViewItem>
impl Allocated<SplitViewItem>
pub fn init(self) -> Retained<SplitViewItem>
Sourceimpl Allocated<TitlebarAccessoryViewController>
impl Allocated<TitlebarAccessoryViewController>
pub fn init(self) -> Retained<TitlebarAccessoryViewController>
Sourceimpl Allocated<ViewController>
impl Allocated<ViewController>
pub fn init(self) -> Retained<ViewController>
Sourceimpl Allocated<ToolbarItem>
impl Allocated<ToolbarItem>
pub fn init(self) -> Retained<ToolbarItem>
Sourceimpl Allocated<ToolbarItem>
impl Allocated<ToolbarItem>
pub fn init_with_item_id(self, id: &ToolbarItemId) -> R<ToolbarItem>
Sourceimpl Allocated<WindowController>
impl Allocated<WindowController>
pub fn init_with_window(self, window: Option<&Window>) -> R<WindowController>
Sourceimpl Allocated<WindowController>
impl Allocated<WindowController>
pub fn init(self) -> Retained<WindowController>
Sourceimpl Allocated<Window>
impl Allocated<Window>
pub fn init_with_content_rect_style_mask_backing_defer( self, content_rect: Rect, style: WindowStyleMask, backing: BackingStoreType, defer: bool, ) -> R<Window>
Sourceimpl Allocated<WorkspaceOpenCfg>
impl Allocated<WorkspaceOpenCfg>
pub fn init(self) -> Retained<WorkspaceOpenCfg>
Sourceimpl Allocated<Connection>
impl Allocated<Connection>
pub fn init_with_service_name(self, name: &String) -> R<Connection>
pub fn init_with_mach_service( self, name: &String, options: ConnectionOptions, ) -> R<Connection>
pub fn init_with_listener_endpoint( self, endpoint: &ListenerEndpoint, ) -> R<Connection>
Sourceimpl Allocated<Listener>
impl Allocated<Listener>
pub fn init_with_mach_service_name(self, name: &String) -> R<Listener>
Sourceimpl Allocated<TextAttachment>
impl Allocated<TextAttachment>
pub fn init(self) -> Retained<TextAttachment>
Sourceimpl Allocated<TextAttachment>
impl Allocated<TextAttachment>
pub fn init_with_data( self, data: Option<&Data>, type_: Option<&String>, ) -> R<TextAttachment>
Sourceimpl Allocated<LangRecognizer>
impl Allocated<LangRecognizer>
pub fn init(self) -> Retained<LangRecognizer>
Sourceimpl Allocated<ContentFilter>
impl Allocated<ContentFilter>
pub fn init_with_desktop_independent_window( self, window: &Window, ) -> Retained<ContentFilter>
Sourcepub fn sel_init_with_desktop_independent_window() -> &'static Sel
pub fn sel_init_with_desktop_independent_window() -> &'static Sel
@selector(initWithDesktopIndependentWindow:) but dynamic
use this function to check if object responds to selector
pub fn init_with_display_excluding_windows( self, display: &Display, windows: &Array<Window>, ) -> Retained<ContentFilter>
Sourcepub fn sel_init_with_display_excluding_windows() -> &'static Sel
pub fn sel_init_with_display_excluding_windows() -> &'static Sel
@selector(initWithDisplay:excludingWindows:) but dynamic
use this function to check if object responds to selector
Sourcepub fn init_with_display_including_windows(
self,
display: &Display,
windows: &Array<Window>,
) -> Retained<ContentFilter>
pub fn init_with_display_including_windows( self, display: &Display, windows: &Array<Window>, ) -> Retained<ContentFilter>
Creates a content filter that includes only the specified windows on the given display.
Use this initializer to capture specific windows from a display. Unlike
init_with_desktop_independent_window, this method works reliably for all
window types including regular application windows.
Sourcepub fn sel_init_with_display_including_windows() -> &'static Sel
pub fn sel_init_with_display_including_windows() -> &'static Sel
@selector(initWithDisplay:includingWindows:) but dynamic
use this function to check if object responds to selector
Sourcepub fn init_with_display_including_apps_excepting_windows(
self,
display: &Display,
apps: &Array<RunningApp>,
excepting_windows: &Array<Window>,
) -> Retained<ContentFilter>
pub fn init_with_display_including_apps_excepting_windows( self, display: &Display, apps: &Array<RunningApp>, excepting_windows: &Array<Window>, ) -> Retained<ContentFilter>
Creates a content filter that includes content from the specified applications, optionally excluding specific windows.
Sourcepub fn sel_init_with_display_including_apps_excepting_windows() -> &'static Sel
pub fn sel_init_with_display_including_apps_excepting_windows() -> &'static Sel
@selector(initWithDisplay:includingApplications:exceptingWindows:) but dynamic
use this function to check if object responds to selector
Sourcepub fn init_with_display_excluding_apps_excepting_windows(
self,
display: &Display,
apps: &Array<RunningApp>,
excepting_windows: &Array<Window>,
) -> Retained<ContentFilter>
pub fn init_with_display_excluding_apps_excepting_windows( self, display: &Display, apps: &Array<RunningApp>, excepting_windows: &Array<Window>, ) -> Retained<ContentFilter>
Creates a content filter that excludes content from the specified applications, optionally excepting specific windows that should still be included.
Sourcepub fn sel_init_with_display_excluding_apps_excepting_windows() -> &'static Sel
pub fn sel_init_with_display_excluding_apps_excepting_windows() -> &'static Sel
@selector(initWithDisplay:excludingApplications:exceptingWindows:) but dynamic
use this function to check if object responds to selector
Sourceimpl Allocated<Stream>
impl Allocated<Stream>
Sourcepub fn init_with_filter_configuration_delegate<D: Delegate>(
self,
filter: &ContentFilter,
configuration: &Cfg,
delegate: Option<&D>,
) -> Retained<Stream>
pub fn init_with_filter_configuration_delegate<D: Delegate>( self, filter: &ContentFilter, configuration: &Cfg, delegate: Option<&D>, ) -> Retained<Stream>
Initializes a stream with a content filter, configuration, and optional delegate.
Sourceimpl Allocated<ScreenshotCfg>
impl Allocated<ScreenshotCfg>
pub fn init(self) -> Retained<ScreenshotCfg>
Sourceimpl Allocated<ScreenshotOutput>
impl Allocated<ScreenshotOutput>
pub fn init(self) -> Retained<ScreenshotOutput>
Sourceimpl Allocated<RecordingOutputCfg>
impl Allocated<RecordingOutputCfg>
pub fn init(self) -> Retained<RecordingOutputCfg>
Sourceimpl Allocated<RecordingOutput>
impl Allocated<RecordingOutput>
Sourcepub fn init_with_cfg_delegate<D: Delegate>(
self,
cfg: &RecordingOutputCfg,
delegate: &D,
) -> Retained<RecordingOutput>
pub fn init_with_cfg_delegate<D: Delegate>( self, cfg: &RecordingOutputCfg, delegate: &D, ) -> Retained<RecordingOutput>
Initializes a recording output with a configuration and delegate.
Sourceimpl Allocated<ClipBufferingOutput>
impl Allocated<ClipBufferingOutput>
Sourcepub fn sel_init_with_delegate() -> &'static Sel
pub fn sel_init_with_delegate() -> &'static Sel
@selector(initWithDelegate:) but dynamic
use this function to check if object responds to selector
Sourcepub unsafe fn init_with_delegate<D: Delegate>(
self,
delegate: Option<&D>,
) -> Retained<ClipBufferingOutput>
pub unsafe fn init_with_delegate<D: Delegate>( self, delegate: Option<&D>, ) -> Retained<ClipBufferingOutput>
Initializes a clip buffering output with an optional delegate.
Sourceimpl Allocated<RecordingEditor>
impl Allocated<RecordingEditor>
Sourcepub fn sel_init_with_url() -> &'static Sel
pub fn sel_init_with_url() -> &'static Sel
@selector(initWithURL:) but dynamic
use this function to check if object responds to selector
Sourcepub unsafe fn init_with_url(self, url: &Url) -> Retained<RecordingEditor>
pub unsafe fn init_with_url(self, url: &Url) -> Retained<RecordingEditor>
Initializes an editor for a recording file URL.
Sourceimpl Allocated<AudioStreamAnalyzer>
impl Allocated<AudioStreamAnalyzer>
pub fn init(self) -> Retained<AudioStreamAnalyzer>
Sourceimpl Allocated<AudioStreamAnalyzer>
impl Allocated<AudioStreamAnalyzer>
pub fn init_with_format(self, format: &AudioFormat) -> R<AudioStreamAnalyzer>
Sourceimpl Allocated<AudioFileAnalyzer>
impl Allocated<AudioFileAnalyzer>
pub fn init(self) -> Retained<AudioFileAnalyzer>
Sourceimpl Allocated<AudioFileAnalyzer>
impl Allocated<AudioFileAnalyzer>
pub unsafe fn init_with_url_err<'ear>( self, url: &Url, error: *mut Option<&'ear Error>, ) -> Option<R<AudioFileAnalyzer>>
Sourceimpl Allocated<Constraint>
impl Allocated<Constraint>
pub fn init_with_duration_range( self, duration_range: TimeRange, ) -> R<Constraint>
pub fn init_with_enumerated_durations( self, durations: &Array<Value>, ) -> R<Constraint>
Sourceimpl Allocated<ClassifySoundRequest>
impl Allocated<ClassifySoundRequest>
pub unsafe fn init_with_classifier_id_err<'ear>( self, id: &Id, err: *mut Option<&'ear Error>, ) -> Option<R<ClassifySoundRequest>>
Sourceimpl Allocated<ClassificationResult>
impl Allocated<ClassificationResult>
pub fn init(self) -> Retained<ClassificationResult>
Sourceimpl Allocated<NotificationContent>
impl Allocated<NotificationContent>
pub fn init(self) -> Retained<NotificationContent>
Sourceimpl Allocated<NotificationContentMut>
impl Allocated<NotificationContentMut>
pub fn init(self) -> Retained<NotificationContentMut>
Sourceimpl Allocated<CalcImageAestheticsScoresRequest>
impl Allocated<CalcImageAestheticsScoresRequest>
pub fn init_with_ch( self, ch: Option<&mut RequestCh<CalcImageAestheticsScoresRequest>>, ) -> R<CalcImageAestheticsScoresRequest>
Sourceimpl Allocated<CalcImageAestheticsScoresRequest>
impl Allocated<CalcImageAestheticsScoresRequest>
pub fn init(self) -> Retained<CalcImageAestheticsScoresRequest>
Sourceimpl Allocated<DetectHorizonRequest>
impl Allocated<DetectHorizonRequest>
pub fn init(self) -> Retained<DetectHorizonRequest>
Sourceimpl Allocated<ImageRequestHandler>
impl Allocated<ImageRequestHandler>
pub fn init_with_url_options( self, url: &Url, options: Option<&Dictionary<Id, Id>>, ) -> R<ImageRequestHandler>
pub fn init_with_url_orientation_options( self, url: &Url, orientation: ImagePropOrientation, options: Option<&Dictionary<Id, Id>>, ) -> R<ImageRequestHandler>
pub fn init_with_cv_pixel_buf_options( self, pb: &PixelBuf, options: Option<&Dictionary<Id, Id>>, ) -> Option<R<ImageRequestHandler>>
pub fn init_with_cv_pixel_buf_orientaion_options( self, pb: &PixelBuf, orientation: ImagePropOrientation, options: Option<&Dictionary<Id, Id>>, ) -> Option<R<ImageRequestHandler>>
Sourceimpl Allocated<SequenceRequestHandler>
impl Allocated<SequenceRequestHandler>
pub fn init(self) -> Retained<SequenceRequestHandler>
Sourceimpl Allocated<StatefulRequest>
impl Allocated<StatefulRequest>
pub fn init_with_frame_analysis_spacing_ch( self, frame_analysis_spacing: Time, ch: Option<&mut RequestCh>, ) -> R<StatefulRequest>
Sourceimpl Allocated<RecognizeTextRequest>
impl Allocated<RecognizeTextRequest>
pub fn init(self) -> Retained<RecognizeTextRequest>
Sourceimpl Allocated<RecognizeAnimalsRequest>
impl Allocated<RecognizeAnimalsRequest>
pub fn init(self) -> Retained<RecognizeAnimalsRequest>
Sourceimpl Allocated<GenForegroundInstanceMaskRequest>
impl Allocated<GenForegroundInstanceMaskRequest>
pub fn init(self) -> Retained<GenForegroundInstanceMaskRequest>
Sourceimpl Allocated<GenPersonSegmentationRequest>
impl Allocated<GenPersonSegmentationRequest>
pub fn init(self) -> Retained<GenPersonSegmentationRequest>
Sourceimpl Allocated<DetectDocumentSegmentationRequest>
impl Allocated<DetectDocumentSegmentationRequest>
pub fn init(self) -> Retained<DetectDocumentSegmentationRequest>
Sourceimpl Allocated<GenAttentionBasedSaliencyImageRequest>
impl Allocated<GenAttentionBasedSaliencyImageRequest>
pub fn init(self) -> Retained<GenAttentionBasedSaliencyImageRequest>
Sourceimpl Allocated<GenObjectnessBasedSaliencyImageRequest>
impl Allocated<GenObjectnessBasedSaliencyImageRequest>
pub fn init(self) -> Retained<GenObjectnessBasedSaliencyImageRequest>
Sourceimpl Allocated<GenImageFeaturePrintRequest>
impl Allocated<GenImageFeaturePrintRequest>
pub fn init_with_ch( self, ch: Option<&mut RequestCh<GenImageFeaturePrintRequest>>, ) -> R<GenImageFeaturePrintRequest>
Sourceimpl Allocated<GenImageFeaturePrintRequest>
impl Allocated<GenImageFeaturePrintRequest>
pub fn init(self) -> Retained<GenImageFeaturePrintRequest>
Sourceimpl Allocated<ClassifyImageRequest>
impl Allocated<ClassifyImageRequest>
pub fn init(self) -> Retained<ClassifyImageRequest>
Sourceimpl Allocated<DetectFaceRectanglesRequest>
impl Allocated<DetectFaceRectanglesRequest>
pub fn init(self) -> Retained<DetectFaceRectanglesRequest>
Sourceimpl Allocated<DetectFaceCaptureQualityRequest>
impl Allocated<DetectFaceCaptureQualityRequest>
pub fn init(self) -> Retained<DetectFaceCaptureQualityRequest>
Sourceimpl Allocated<DetectBarcodesRequest>
impl Allocated<DetectBarcodesRequest>
pub fn init(self) -> Retained<DetectBarcodesRequest>
Sourceimpl Allocated<FrameRateCadence>
impl Allocated<FrameRateCadence>
pub fn init_with_frame_rate(self, frame_rate: isize) -> R<FrameRateCadence>
Sourceimpl Allocated<TimeIntervalCadence>
impl Allocated<TimeIntervalCadence>
pub fn init_with_time_interval( self, time_interval: TimeInterval, ) -> R<TimeIntervalCadence>
Sourceimpl Allocated<RequestProcessingOpts>
impl Allocated<RequestProcessingOpts>
pub fn init(self) -> Retained<RequestProcessingOpts>
Sourceimpl Allocated<VideoProcessor>
impl Allocated<VideoProcessor>
pub fn init_with_url(self, url: &Url) -> R<VideoProcessor>
Sourcepub fn sel_init_with_url() -> &'static Sel
pub fn sel_init_with_url() -> &'static Sel
@selector(initWithURL:) but dynamic
use this function to check if object responds to selector