#[repr(isize)]pub enum VideoStabilizationMode {
Off = 0,
Standard = 1,
Cinematic = 2,
CinematicExtended = 3,
PreviewOptimized = 4,
CinematicExtendedEnhanced = 5,
Auto = -1,
}Variants
Off = 0
Indicates that video should not be stabilized.
Standard = 1
Indicates that video should be stabilized using the standard video stabilization algorithm introduced with iOS 5.0. Standard video stabilization has a reduced field of view. Enabling video stabilization may introduce additional latency into the video capture pipeline.
Cinematic = 2
Indicates that video should be stabilized using the cinematic stabilization algorithm for more dramatic results. Cinematic video stabilization has a reduced field of view compared to standard video stabilization. Enabling cinematic video stabilization introduces much more latency into the video capture pipeline than standard video stabilization and consumes significantly more system memory. Use narrow or identical min and max frame durations in conjunction with this mode.
CinematicExtended = 3
Indicates that the video should be stabilized using the extended cinematic stabilization algorithm. Enabling extended cinematic stabilization introduces longer latency into the video capture pipeline compared to the ‘av::CaptureVideoStabilizationMode::Cinematic’ and consumes more memory, but yields improved stability. It is recommended to use identical or similar min and max frame durations in conjunction with this mode.
PreviewOptimized = 4
Indicates that video should be stabilized using the preview optimized stabilization algorithm. Preview stabilization is a low latency and low power algorithm which is supported only on connections which either have an associated preview layer or have a preview-sized VideoDataOutput.
CinematicExtendedEnhanced = 5
Enhanced extended cinematic has a reduced field of view compared to extended cinematic, without any noticeable increase in latency, and it yields improved stability.
It’s recommended to use identical or similar minimum and maximum frame durations in conjunction with this mode.
Auto = -1
Indicates that the most appropriate video stabilization mode for the device and format should be chosen.