pub struct Type(/* private fields */);Implementations
Sourceimpl Type
impl Type
pub fn human_body() -> &'static Type
pub fn human_full_body() -> &'static Type
pub fn cat_body() -> &'static Type
pub fn dog_body() -> &'static Type
pub fn salient_object() -> &'static Type
pub fn face() -> &'static Type
Sourcepub fn upc_e_code() -> &'static Type
pub fn upc_e_code() -> &'static Type
objects generated from UPC-E codes return this constant as their type.
Sourcepub fn code_39_code() -> &'static Type
pub fn code_39_code() -> &'static Type
objects generated from Code 39 codes return this constant as their type.
Sourcepub fn code_39_mod_43_code() -> &'static Type
pub fn code_39_mod_43_code() -> &'static Type
objects generated from Code 39 mod 43 codes return this constant as their type.
Sourcepub fn ean_13_code() -> &'static Type
pub fn ean_13_code() -> &'static Type
objects generated from EAN-13 (including UPC-A) codes return this constant as their type.
Sourcepub fn ean_8_code() -> &'static Type
pub fn ean_8_code() -> &'static Type
objects generated from EAN-8 codes return this constant as their type.
Sourcepub fn code_93_code() -> &'static Type
pub fn code_93_code() -> &'static Type
objects generated from Code 93 codes return this constant as their type.
Sourcepub fn code_128_code() -> &'static Type
pub fn code_128_code() -> &'static Type
objects generated from Code 128 codes return this constant as their type.
Sourcepub fn pdf_417_code() -> &'static Type
pub fn pdf_417_code() -> &'static Type
objects generated from PDF417 codes return this constant as their type
Sourcepub fn qr_code() -> &'static Type
pub fn qr_code() -> &'static Type
objects generated from QR codes return this constant as their type.
Sourcepub fn aztec_code() -> &'static Type
pub fn aztec_code() -> &'static Type
objects generated from Aztec codes return this constant as their type.
Sourcepub fn interleaved_2_to_5_code() -> &'static Type
pub fn interleaved_2_to_5_code() -> &'static Type
objects generated from Interleaved 2 of 5 codes return this constant as their type.
Sourcepub fn itf_14_code() -> &'static Type
pub fn itf_14_code() -> &'static Type
objects generated from ITF14 codes return this constant as their type.
Sourcepub fn data_matrix_code() -> &'static Type
pub fn data_matrix_code() -> &'static Type
objects generated from DataMatrix codes return this constant as their type.
Sourcepub fn codebar_code() -> &'static Type
pub fn codebar_code() -> &'static Type
objects generated from Codabar codes return this constant as their type.
Sourcepub fn gs_1_data_bar_code() -> &'static Type
pub fn gs_1_data_bar_code() -> &'static Type
objects generated from GS1DataBar codes return this constant as their type.
Sourcepub fn gs_1_data_bar_expanded_code() -> &'static Type
pub fn gs_1_data_bar_expanded_code() -> &'static Type
objects generated from GS1DataBarExpanded codes return this constant as their type.
Sourcepub fn gs_1_data_bar_limited_code() -> &'static Type
pub fn gs_1_data_bar_limited_code() -> &'static Type
objects generated from GS1DataBarLimited codes return this constant as their type.
Sourcepub fn micro_qr_code() -> &'static Type
pub fn micro_qr_code() -> &'static Type
objects generated from MicroQR codes return this constant as their type.
Sourcepub fn micro_pdf_417_code() -> &'static Type
pub fn micro_pdf_417_code() -> &'static Type
objects generated from MicroPDF417 codes return this constant as their type.
Methods from Deref<Target = String>
pub fn retained(&self) -> R<Self>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn lowercased_ar(&self) -> Rar<Self>
pub fn lowercased(&self) -> R<Self>
pub fn to_i32(&self) -> i32
pub fn to_i64(&self) -> i64
pub fn to_f32(&self) -> f32
pub fn to_f64(&self) -> f64
pub fn to_bool(&self) -> bool
Sourcepub fn to_integer(&self) -> Integer
pub fn to_integer(&self) -> Integer
The ns::Integer value of the string.
The ns::Integer value of the string, assuming a decimal representation and skipping whitespace at the beginning of the string. This property is 0 if the string doesn’t begin with a valid decimal text representation of a number. This property uses formatting information stored in the non-localized value; use an ns::Scanner object for localized scanning of numeric values from a string.
pub fn copy_mut(&self) -> Retained<StringMut>
Sourcepub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
pub unsafe fn substring_with_range_throws_ar(&self, range: Range) -> Rar<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.
Sourcepub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
pub unsafe fn substring_with_range_throws(&self, range: Range) -> R<Self>
Returns a substring for range.
Safety
Throws an Objective-C exception if range is outside the string bounds.