#[repr(transparent)]pub struct RunStatus(pub u32);Tuple Fields
0: u32Implementations
Sourceimpl Status
impl Status
Sourcepub const RIGHT_TO_LEFT: Self
pub const RIGHT_TO_LEFT: Self
When set, the run is right to left.
Sourcepub const NON_MONOTONIC: Self
pub const NON_MONOTONIC: Self
When set, the run has been reordered in some way such that the string indices associated with the glyphs are no longer strictly increasing (for left to right runs) or decreasing (for right to left runs).
Sourcepub const HAS_NON_IDENTITY_MATRIX: Self
pub const HAS_NON_IDENTITY_MATRIX: Self
When set, the run requires a specific text matrix to be set in the current CG context for proper drawing.