pub struct Service(/* private fields */);Implementations
Sourceimpl Service
impl Service
Sourcepub const MAX_SERVICE_NAME: usize = 64
pub const MAX_SERVICE_NAME: usize = 64
Maximum length, in bytes, of a service name represented as a literal C-String, including the terminating NULL at the end.
Sourcepub const MAX_DOMAIN_NAME: usize = 1009
pub const MAX_DOMAIN_NAME: usize = 1009
Maximum length, in bytes, of a domain name represented as an escaped C-String including the final trailing dot, and the C-String terminating NULL at the end.
Sourcepub fn sock_fd(&self) -> Sock
pub fn sock_fd(&self) -> Sock
Access underlying Unix domain socket for an initialized DNSServiceRef.
pub fn process_result(&self) -> Result
pub fn deallocate(self)