#[repr(isize)]pub enum SessionSendDataMode {
Reliable = 0,
Unreliable = 1,
}Variants
Reliable = 0
Guaranteed reliable and in-order delivery.
The framework should guarantee delivery of each message, enqueueing and retransmitting data as needed, and ensuring in-order delivery
Use this message type for application-critical data.
Unreliable = 1
Sent immediately without queuing, no guaranteed delivery.
Messages to peers should be sent immediately without socket-level queueing. If a message cannot be sent immediately, it should be dropped. The order of messages is not guaranteed.
Use this message type for data that ceases to be relevant if delayed, such as real-time gaming data.