pub struct BlockOp(/* private fields */);Implementations
Methods from Deref<Target = Op>
pub fn retained(&self) -> R<Self>
pub fn is_cancelled(&self) -> bool
pub fn cancel(&mut self)
Sourcepub fn is_executing(&self) -> bool
pub fn is_executing(&self) -> bool
A bool value indicating whether the operation is currently executing.
pub fn is_finished(&self) -> bool
pub fn is_ready(&self) -> bool
Sourcepub fn add_dependency(&mut self, val: &Op)
pub fn add_dependency(&mut self, val: &Op)
Makes the receiver dependent on the completion of the specified operation.
The receiver is not considered ready to execute until all of its dependent operations have finished executing. If the receiver is already executing its task, adding dependencies has no practical effect. This method may change the isReady and dependencies properties of the receiver.
It is a programmer error to create any circular dependencies among a set of operations. Doing so can cause a deadlock among the operations and may freeze your program.
Sourcepub fn remove_dependency(&mut self, val: &Op)
pub fn remove_dependency(&mut self, val: &Op)
Removes the receiver’s dependence on the specified operation.
Sourcepub fn dependencies_ar(&self) -> Rar<Array<Op>>
pub fn dependencies_ar(&self) -> Rar<Array<Op>>
An array of the operation objects that must finish executing before the current object can begin executing.
Sourcepub fn dependencies(&self) -> R<Array<Op>>
pub fn dependencies(&self) -> R<Array<Op>>
An array of the operation objects that must finish executing before the current object can begin executing.