pub struct Type(/* private fields */);Implementations
Sourceimpl Type
impl Type
pub fn cls() -> &'static Class<Self>
pub fn cls_ptr() -> *const c_void
pub fn alloc() -> A<Self>
pub fn with_id_ar(identifier: &String) -> Option<Rar<Self>>
pub fn with_id(identifier: &String) -> Option<R<Self>>
pub fn with_file_ext_ar(file_name_extension: &String) -> Option<Rar<Self>>
pub fn with_file_ext(file_name_extension: &String) -> Option<R<Self>>
pub fn id_ar(&self) -> Rar<String>
pub fn id(&self) -> R<String>
pub fn preferred_file_ext_ar(&self) -> Option<Rar<String>>
pub fn preferred_file_ext(&self) -> Option<R<String>>
pub fn preferred_mime_type_ar(&self) -> Option<Rar<String>>
pub fn preferred_mime_type(&self) -> Option<R<String>>
pub fn localized_desc_ar(&self) -> Option<Rar<String>>
pub fn localized_desc(&self) -> Option<R<String>>
pub fn version_ar(&self) -> Option<Rar<String>>
pub fn version(&self) -> Option<R<String>>
pub fn reference_url_ar(&self) -> Option<Rar<Url>>
pub fn reference_url(&self) -> Option<R<Url>>
pub fn is_dynamic(&self) -> bool
pub fn is_declared(&self) -> bool
pub fn is_public_type(&self) -> bool
Sourceimpl Type
Conformance
impl Type
Conformance
pub fn conforms_to_type(&self, other: &Self) -> bool
pub fn is_supertype_of_type(&self, other: &Self) -> bool
pub fn is_subtype_of_type(&self, other: &Self) -> bool
pub fn supertypes_ar(&self) -> Rar<Set<Self>>
pub fn supertypes(&self) -> R<Set<Self>>
Sourceimpl Type
Abstract base types
impl Type
Abstract base types
Sourcepub fn item() -> &'static Self
pub fn item() -> &'static Self
A generic base type for most things (files, directories.)
UTI: public.item
Sourcepub fn content() -> &'static Self
pub fn content() -> &'static Self
A base type for anything containing user-viewable document content (documents, pasteboard data, and document packages.)
UTI: public.content
Sourcepub fn composite_content() -> &'static Self
pub fn composite_content() -> &'static Self
A base type for content formats supporting mixed embedded content (i.e., compound documents).
UTI: public.composite-content conforms to: public.content
Sourcepub fn disk_image() -> &'static Self
pub fn disk_image() -> &'static Self
A data item mountable as a volume
UTI: public.disk-image
Sourceimpl Type
Concrete base types
impl Type
Concrete base types
Sourcepub fn data() -> &'static Self
pub fn data() -> &'static Self
A base type for any sort of simple byte stream, including files and in-memory data.
UTI: public.data conforms to: public.item
Sourcepub fn directory() -> &'static Self
pub fn directory() -> &'static Self
A file system directory (includes packages \em and folders.)
UTI: public.directory conforms to: public.item
Sourcepub fn resolvable() -> &'static Self
pub fn resolvable() -> &'static Self
Symbolic link and alias file types conform to this type.
UTI: com.apple.resolvable
Sourcepub fn symbolic_link() -> &'static Self
pub fn symbolic_link() -> &'static Self
A symbolic link.
UTI: public.symlink conforms to: public.item, com.apple.resolvable
Sourcepub fn executable() -> &'static Self
pub fn executable() -> &'static Self
An executable item.
UTI: public.executable conforms to: public.item
Sourcepub fn mount_point() -> &'static Self
pub fn mount_point() -> &'static Self
A volume mount point (resolvable, resolves to the root directory of a volume.)
UTI: com.apple.mount-point conforms to: public.item, com.apple.resolvable
Sourcepub fn alias_file() -> &'static Self
pub fn alias_file() -> &'static Self
A fully-formed alias file.
UTI: com.apple.alias-file conforms to: public.data, com.apple.resolvable
Sourceimpl Type
URL types
impl Type
URL types
Sourcepub fn url_bookmark_data() -> &'static Self
pub fn url_bookmark_data() -> &'static Self
A URL bookmark.
UTI: com.apple.bookmark conforms to: public.data, com.apple.resolvable
Sourceimpl Type
Text types
impl Type
Text types
Sourcepub fn text() -> &'static Self
pub fn text() -> &'static Self
The base type for all text-encoded data, including text with markup (HTML, RTF, etc.).
UTI: public.text conforms to: public.data, public.content
Sourcepub fn plain_text() -> &'static Self
pub fn plain_text() -> &'static Self
Text with no markup and an unspecified encoding.
UTI: public.plain-text conforms to: public.text
Sourcepub fn utf8_plain_text() -> &'static Self
pub fn utf8_plain_text() -> &'static Self
Plain text encoded as UTF-8.
UTI: public.utf8-plain-text conforms to: public.plain-text
Sourcepub fn utf16_external_plain_text() -> &'static Self
pub fn utf16_external_plain_text() -> &'static Self
Plain text encoded as UTF-16 with a BOM, or if a BOM is not present, using “external representation” byte order (big-endian).
UTI: public.utf16-external-plain-text conforms to: public.plain-text
Sourcepub fn utf16_plain_text() -> &'static Self
pub fn utf16_plain_text() -> &'static Self
Plain text encoded as UTF-16, in native byte order, with an optional BOM.
UTI: public.utf16-plain-text conforms to: public.plain-text
Sourcepub fn delimited_text() -> &'static Self
pub fn delimited_text() -> &'static Self
Text containing delimited values.
UTI: public.delimited-values-text conforms to: public.text
Sourcepub fn comma_separated_text() -> &'static Self
pub fn comma_separated_text() -> &'static Self
Text containing comma-separated values (.csv).
UTI: public.comma-separated-values-text conforms to: public.delimited-values-text
Sourcepub fn tab_separated_text() -> &'static Self
pub fn tab_separated_text() -> &'static Self
Text containing tab-separated values.
UTI: public.tab-separated-values-text conforms to: public.delimited-values-text
Sourcepub fn utf8_tab_separated_text() -> &'static Self
pub fn utf8_tab_separated_text() -> &'static Self
UTF-8 encoded text containing tab-separated values.
UTI: public.utf8-tab-separated-values-text conforms to: public.tab-separated-values-text, public.utf8-plain-text
Sourceimpl Type
Programming languages
impl Type
Programming languages
Sourcepub fn src_code() -> &'static Self
pub fn src_code() -> &'static Self
Abstract type for source code of any language.
UTI: public.source-code conforms to: public.plain-text
Sourcepub fn asm_src() -> &'static Self
pub fn asm_src() -> &'static Self
Assembly language source (.s)
UTI: public.assembly-source conforms to: public.source-code
Sourcepub fn c_src() -> &'static Self
pub fn c_src() -> &'static Self
C source code (.c)
UTI: public.c-source conforms to: public.source-code
Sourcepub fn obj_c_src() -> &'static Self
pub fn obj_c_src() -> &'static Self
Objective-C source code (.m)
UTI: public.objective-c-source conforms to: public.source-code
Sourcepub fn swift_src() -> &'static Self
pub fn swift_src() -> &'static Self
Swift source code (.swift)
UTI: public.swift-source conforms to: public.source-code
Sourcepub fn cpp_src() -> &'static Self
pub fn cpp_src() -> &'static Self
C++ source code (.cp, etc.)
UTI: public.c-plus-plus-source conforms to: public.source-code
Sourcepub fn obj_cpp_src() -> &'static Self
pub fn obj_cpp_src() -> &'static Self
Objective-C++ source code.
UTI: public.objective-c-plus-plus-source conforms to: public.source-code
Sourcepub fn c_header() -> &'static Self
pub fn c_header() -> &'static Self
A C header.
UTI: public.c-header conforms to: public.source-code
Sourcepub fn cpp_header() -> &'static Self
pub fn cpp_header() -> &'static Self
A C++ header.
UTI: public.c-plus-plus-header conforms to: public.source-code
Sourceimpl Type
Scripting languages
impl Type
Scripting languages
Sourcepub fn script() -> &'static Self
pub fn script() -> &'static Self
A base type for any scripting language source.
UTI: public.script conforms to: public.source-code
Sourcepub fn apple_script() -> &'static Self
pub fn apple_script() -> &'static Self
An AppleScript text-based script (.applescript).
UTI: com.apple.applescript.text conforms to: public.script
Sourcepub fn osa_script() -> &'static Self
pub fn osa_script() -> &'static Self
An Open Scripting Architecture binary script (.scpt).
UTI: com.apple.applescript.script conforms to: public.data, public.script
Sourcepub fn osa_script_bundle() -> &'static Self
pub fn osa_script_bundle() -> &'static Self
An Open Scripting Architecture script bundle (.scptd).
UTI: com.apple.applescript.script-bundle conforms to: com.apple.bundle, com.apple.package, public.script
Sourcepub fn java_script() -> &'static Self
pub fn java_script() -> &'static Self
JavaScript source code
UTI: com.netscape.javascript-source conforms to: public.source-code, public.executable
Sourcepub fn shell_script() -> &'static Self
pub fn shell_script() -> &'static Self
The base type for shell scripts.
UTI: public.shell-script conforms to: public.script
Sourcepub fn perl_script() -> &'static Self
pub fn perl_script() -> &'static Self
A Perl script.
UTI: public.perl-script conforms to: public.shell-script
Sourcepub fn python_script() -> &'static Self
pub fn python_script() -> &'static Self
A Python script.
UTI: public.python-script conforms to: public.shell-script
Sourcepub fn ruby_script() -> &'static Self
pub fn ruby_script() -> &'static Self
A Ruby script.
UTI: public.ruby-script conforms to: public.shell-script
Sourcepub fn php_script() -> &'static Self
pub fn php_script() -> &'static Self
A PHP script.
UTI: public.php-script conforms to: public.shell-script
Sourceimpl Type
Serialized data types
impl Type
Serialized data types
Sourcepub fn json() -> &'static Self
pub fn json() -> &'static Self
JavaScript object notation (JSON) data
UTI: public.json conforms to: public.text JSON almost (but doesn’t quite) conforms to com.netscape.javascript-source.
Sourcepub fn prop_list() -> &'static Self
pub fn prop_list() -> &'static Self
A base type for property lists.
UTI: com.apple.property-list conforms to: public.data
Sourcepub fn xml_prop_list() -> &'static Self
pub fn xml_prop_list() -> &'static Self
An XML property list.
UTI: com.apple.xml-property-list conforms to: public.xml, com.apple.property-list
Sourcepub fn binary_prop_list() -> &'static Self
pub fn binary_prop_list() -> &'static Self
A binary property list.
UTI: com.apple.binary-property-list conforms to: com.apple.property-list
Sourceimpl Type
Composite content types
impl Type
Composite content types
Sourcepub fn pdf() -> &'static Self
pub fn pdf() -> &'static Self
An Adobe PDF document.
UTI: com.adobe.pdf conforms to: public.data, public.composite-content
Sourcepub fn rtfd() -> &'static Self
pub fn rtfd() -> &'static Self
A Rich Text Format Directory document (RTF with content embedding in its on-disk format.)
UTI: com.apple.rtfd conforms to: com.apple.package, public.composite-content
Sourcepub fn flat_rtfd() -> &'static Self
pub fn flat_rtfd() -> &'static Self
A flattened RTFD document (formatted for the pasteboard.)
UTI: com.apple.flat-rtfd conforms to: public.data, public.composite-content
Sourcepub fn web_archive() -> &'static Self
pub fn web_archive() -> &'static Self
The WebKit webarchive format.
UTI: com.apple.webarchive conforms to: public.data, public.composite-content
Sourceimpl Type
Image content types
impl Type
Image content types
Sourcepub fn image() -> &'static Self
pub fn image() -> &'static Self
A base type for abstract image data.
UTI: public.image conforms to: public.data, public.content
Sourcepub fn bmp() -> &'static Self
pub fn bmp() -> &'static Self
A Windows bitmap.
UTI: com.microsoft.bmp conforms to: public.image
Sourcepub fn ico() -> &'static Self
pub fn ico() -> &'static Self
Windows icon data
UTI: com.microsoft.ico conforms to: public.image
Sourcepub fn raw_image() -> &'static Self
pub fn raw_image() -> &'static Self
A base type for raw image data (.raw).
UTI: public.camera-raw-image conforms to: public.image
Sourcepub fn svg() -> &'static Self
pub fn svg() -> &'static Self
A Scalable Vector Graphics image.
UTI: public.svg-image conforms to: public.image
Sourcepub fn live_photo() -> &'static Self
pub fn live_photo() -> &'static Self
A Live Photo.
UTI: com.apple.live-photo
Sourcepub fn heif() -> &'static Self
pub fn heif() -> &'static Self
A High Efficiency Image File Format image.
UTI: public.heif conforms to: public.heif-standard
Sourceimpl Type
3D Content
impl Type
3D Content
Sourcepub fn _3d_content() -> &'static Self
pub fn _3d_content() -> &'static Self
A base type for 3D content.
UTI: public.3d-content conforms to: public.content
Sourcepub fn usd() -> &'static Self
pub fn usd() -> &'static Self
Universal Scene Description content.
UTI: com.pixar.universal-scene-description conforms to: public.3d-content, public.data
Sourcepub fn usdz() -> &'static Self
pub fn usdz() -> &'static Self
Universal Scene Description Package content.
UTI: com.pixar.universal-scene-description-mobile conforms to: public.3d-content, public.data
Sourcepub fn reality_file() -> &'static Self
pub fn reality_file() -> &'static Self
A Reality File.
UTI: com.apple.reality conforms to: public.data
Sourcepub fn sk_scene() -> &'static Self
pub fn sk_scene() -> &'static Self
A SceneKit serialized scene.
UTI: com.apple.scenekit.scene conforms to: public.3d-content, public.data
Sourcepub fn ar_reference_obj() -> &'static Self
pub fn ar_reference_obj() -> &'static Self
An AR reference object.
UTI: com.apple.arobject conforms to: public.data
Sourcepub fn av_content() -> &'static Self
pub fn av_content() -> &'static Self
Any audio and/or video content.
UTI: public.audiovisual-content conforms to: public.data, public.content
Sourcepub fn movie() -> &'static Self
pub fn movie() -> &'static Self
A media format which may contain both video and audio.
This type corresponds to what users would label a “movie”.
UTI: public.movie conforms to: public.audiovisual-content
Sourcepub fn video() -> &'static Self
pub fn video() -> &'static Self
Pure video data with no audio data.
UTI: public.video conforms to: public.movie
Sourcepub fn audio() -> &'static Self
pub fn audio() -> &'static Self
Pure audio data with no video data.
UTI: public.audio conforms to: public.audiovisual-content
Sourcepub fn quick_time_movie() -> &'static Self
pub fn quick_time_movie() -> &'static Self
A QuickTime movie.
UTI: com.apple.quicktime-movie conforms to: public.movie
Sourcepub fn mpeg() -> &'static Self
pub fn mpeg() -> &'static Self
An MPEG-1 or MPEG-2 movie.
UTI: public.mpeg conforms to: public.movie
Sourcepub fn mpeg2video() -> &'static Self
pub fn mpeg2video() -> &'static Self
An MPEG-2 video.
UTI: public.mpeg-2-video conforms to: public.video
Sourcepub fn mpeg2ts() -> &'static Self
pub fn mpeg2ts() -> &'static Self
The MPEG-2 Transport Stream movie format.
UTI: public.mpeg-2-transport-stream conforms to: public.movie
Sourcepub fn mpeg4movie() -> &'static Self
pub fn mpeg4movie() -> &'static Self
MPEG-4 movie
UTI: public.mpeg-4 conforms to: public.movie
Sourcepub fn mpeg4audio() -> &'static Self
pub fn mpeg4audio() -> &'static Self
An MPEG-4 audio layer file.
UTI: public.mpeg-4-audio conforms to: public.mpeg-4, public.audio
Sourcepub fn apple_protected_mpeg4audio() -> &'static Self
pub fn apple_protected_mpeg4audio() -> &'static Self
The Apple protected MPEG4 format (.m4p, iTunes music store format.)
UTI: com.apple.protected-mpeg-4-audio conforms to: public.audio
Sourcepub fn apple_protected_mpeg4video() -> &'static Self
pub fn apple_protected_mpeg4video() -> &'static Self
An Apple protected MPEG-4 movie.
UTI: com.apple.protected-mpeg-4-video conforms to: com.apple.m4v-video
Sourcepub fn aiff() -> &'static Self
pub fn aiff() -> &'static Self
The AIFF audio format
UTI: public.aiff-audio conforms to: public.aifc-audio
Sourcepub fn wav() -> &'static Self
pub fn wav() -> &'static Self
The Microsoft waveform audio format (.wav).
UTI: com.microsoft.waveform-audio conforms to: public.audio
Sourcepub fn midi() -> &'static Self
pub fn midi() -> &'static Self
The MIDI audio format.
UTI: public.midi-audio conforms to: public.audio
Sourcepub fn m3u_playlist() -> &'static Self
pub fn m3u_playlist() -> &'static Self
An M3U or M3U8 playlist
UTI: public.m3u-playlist conforms to: public.text, public.playlist
Sourceimpl Type
Directory types
impl Type
Directory types
Sourcepub fn folder() -> &'static Self
pub fn folder() -> &'static Self
A user-browsable directory (i.e. not a package.)
UTI: public.folder conforms to: public.directory
Sourcepub fn volume() -> &'static Self
pub fn volume() -> &'static Self
The root folder of a volume or mount point.
UTI: public.volume conforms to: public.folder
Sourcepub fn package() -> &'static Self
pub fn package() -> &'static Self
A packaged directory.
UTI: com.apple.package conforms to: public.directory
Sourcepub fn bundle() -> &'static Self
pub fn bundle() -> &'static Self
A directory conforming to one of the \c CFBundle layouts.
UTI: com.apple.bundle conforms to: public.directory
Sourcepub fn plugin_bundle() -> &'static Self
pub fn plugin_bundle() -> &'static Self
The base type for bundle-based plugins.
UTI: com.apple.plugin conforms to: com.apple.bundle, com.apple.package
Sourcepub fn spotlight_importer() -> &'static Self
pub fn spotlight_importer() -> &'static Self
A Spotlight metadata importer bundle.
UTI: com.apple.metadata-importer conforms to: com.apple.plugin
Sourcepub fn quick_look_generator() -> &'static Self
pub fn quick_look_generator() -> &'static Self
A QuickLook preview generator bundle.
UTI: com.apple.quicklook-generator conforms to: com.apple.plugin
Sourcepub fn xpc_service() -> &'static Self
pub fn xpc_service() -> &'static Self
An XPC service bundle.
UTI: com.apple.xpc-service conforms to: com.apple.bundle, com.apple.package
Sourcepub fn framework() -> &'static Self
pub fn framework() -> &'static Self
A macOS or iOS framework bundle.
UTI: com.apple.framework conforms to: com.apple.bundle
Sourcepub fn app() -> &'static Self
pub fn app() -> &'static Self
The base type for macOS and iOS applications.
UTI: com.apple.application conforms to: public.executable
Sourcepub fn app_bundle() -> &'static Self
pub fn app_bundle() -> &'static Self
A bundled application.
UTI: com.apple.application-bundle conforms to: com.apple.application, com.apple.bundle, com.apple.package
Sourcepub fn appex() -> &'static Self
pub fn appex() -> &'static Self
An application extension (.appex).
UTI: com.apple.application-and-system-extension conforms to: com.apple.xpc-service
Sourcepub fn unix_executable() -> &'static Self
pub fn unix_executable() -> &'static Self
A UNIX executable (flat file.)
UTI: public.unix-executable conforms to: public.data, public.executable
Sourcepub fn exe() -> &'static Self
pub fn exe() -> &'static Self
A Windows executable (.exe).
UTI: com.microsoft.windows-executable conforms to: public.data, public.executable
Sourcepub fn sys_pref_pane() -> &'static Self
pub fn sys_pref_pane() -> &'static Self
A System Preferences pane.
UTI: com.apple.systempreference.prefpane conforms to: com.apple.package, com.apple.bundle
Sourceimpl Type
Archival and compression types
impl Type
Archival and compression types
Sourcepub fn gzip() -> &'static Self
pub fn gzip() -> &'static Self
A GNU zip archive.
UTI: org.gnu.gnu-zip-archive conforms to: public.data, public.archive
Sourcepub fn bz2() -> &'static Self
pub fn bz2() -> &'static Self
A bzip2 archive.
UTI: public.bzip2-archive conforms to: public.data, public.archive
Sourcepub fn zip() -> &'static Self
pub fn zip() -> &'static Self
A zip archive.
UTI: public.zip-archive conforms to: com.pkware.zip-archive
Sourcepub fn apple_archive() -> &'static Self
pub fn apple_archive() -> &'static Self
An Apple Archive.
UTI: com.apple.archive conforms to: public.data, public.archive
Sourceimpl Type
Document types
impl Type
Document types
Sourcepub fn spreadsheet() -> &'static Self
pub fn spreadsheet() -> &'static Self
A base type for spreadsheet documents.
UTI: public.spreadsheet conforms to: public.content
Sourcepub fn presentation() -> &'static Self
pub fn presentation() -> &'static Self
A base type for presentation documents.
UTI: public.presentation conforms to: public.composite-content
Sourceimpl Type
Messages, contacts, and calendar types
impl Type
Messages, contacts, and calendar types
Sourcepub fn message() -> &'static Self
pub fn message() -> &'static Self
A base type for messages (email, IM, etc.)
UTI: public.message
Sourcepub fn contact() -> &'static Self
pub fn contact() -> &'static Self
Contact information, e.g. for a person, group, organization
UTI: public.contact
Sourcepub fn v_card() -> &'static Self
pub fn v_card() -> &'static Self
A vCard file.
UTI: public.vcard conforms to: public.text, public.contact
Sourcepub fn calendar_event() -> &'static Self
pub fn calendar_event() -> &'static Self
A calendar event.
UTI: public.calendar-event
Sourcepub fn email_message() -> &'static Self
pub fn email_message() -> &'static Self
An e-mail message.
UTI: public.email-message conforms to: public.message
Sourceimpl Type
Internet locations
impl Type
Internet locations
Sourcepub fn internet_location() -> &'static Self
pub fn internet_location() -> &'static Self
A base type for Apple Internet location files.
UTI: com.apple.internet-location conforms to: public.data
Sourcepub fn internet_shortcut() -> &'static Self
pub fn internet_shortcut() -> &'static Self
Microsoft Internet shortcut files (.url).
UTI: com.apple.internet-location conforms to: public.data